(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    225818,       5254]*)
(*NotebookOutlinePosition[    260089,       6488]*)
(*  CellTagsIndexPosition[    259955,       6481]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Dimensional Analysis", "Title",
  TextAlignment->Center,
  TextJustification->0],

Cell[TextData[{
  "from ",
  StyleBox[ButtonBox["Essential Mathematica for Students of Science",
    Active->False,
    ButtonData:>{
      URL[ 
      "http://www.physics.umd.edu/courses/CourseWare/EssentialMathematica/"], 
      None},
    Active->False,
    ButtonStyle->"Hyperlink"],
    Active->False],
  "\n\[Copyright] James J. Kelly, 1998\nLast revised: January, 2006"
}], "Author",
  Active->True,
  TextAlignment->Center,
  TextJustification->0],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "In science and engineering one is constantly manipulating functions and \
relationships that involve quantities with physical dimensions and whose \
numerical values depend upon the system of units employed.  In fact, your \
previous instructors probably insisted that the value obtained for any \
dimensioned quantity must be accompanied by its units and you were probably \
annoyed by losing credit on homework and tests for omitting units from \
numerically correct results.  The reason for insisting upon carrying the \
units is that relationships that are not dimensionally consistent cannot be \
meaningful and numerical calculations that are not expressed in a consistent \
set of units will not be correct either even if dimensionally consistent.  \
However, those of you who have computed physical quantities using a computer \
quickly discovered that compiled languages handle only numerical values and \
do not readily accommodate units \[LongDash] all quantities must be expressed \
numerically and it is the programmer's responsibility to ensure consistency \
of both dimensions and units.  Interpreted languages, like ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", permit units to be attached to values in the form of symbolic factors \
and conversions to be expressed by replacement rules.  Thus, it is possible \
to satisfy the professor's insistence upon units and still enjoy the \
advantages of electronic computation.  However, because many operations, like \
plotting, remain limited to purely numerical quantities, symbolic units can \
still be more of a nuisance than a help."
}], "Text"],

Cell["\<\
In this notebook we explore some of the techniques for manipulating \
dimensioned quantities.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[{
    \(\(ClearAll["\<Global`*\>"];\)\), "\n", 
    \(Off[General::spell, General::spell1]\)}], "Input"],

Cell[BoxData[{
    \(\(Needs["\<Miscellaneous`PhysicalConstants`\>"];\)\), "\n", 
    \(Needs["\<Miscellaneous`Units`\>"]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Verifying dimensional consistency", "Section"],

Cell["\<\
Suppose you derive or are given an equation involving dimensioned quantities \
and wish to verify that the dimensions are consistent.  If you were doing \
this by hand, you would express all symbols in terms of their fundamental \
dimensions:  Mass, Length, Time, Temperature, etc.  Then you would verify \
that each term has the same dimensions, meaning that the powers match, while \
ignoring numerical coefficients.  \
\>", "Text"],

Cell[TextData[{
  "For example, the gravitational acceleration ",
  StyleBox["g",
    FontSlant->"Italic"],
  " at radius ",
  StyleBox["r",
    FontSlant->"Italic"],
  " outside a sphere of mass ",
  StyleBox["M",
    FontSlant->"Italic"],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm\`g = \(G\ M\)\/r\^2\)]],
  " where ",
  StyleBox["G",
    FontSlant->"Italic"],
  " is the gravitational constant.  We verify the dimensional consistency of \
this formula below."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g \[Equal] \(G\ M\)\/r\^2 //. {g \[Rule] Acceleration, 
        Acceleration \[Rule] Length\/Time\^2, M \[Rule] Mass, 
        r \[Rule] Length, G \[Rule] Force\/\((Mass\^2/Length\^2)\), 
        Force \[Rule] Mass\ Acceleration}\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Closed]],

Cell["\<\
Of course, this example is so simple that formulating these rules might seem \
to be more trouble than it's worth.  However, if we collect these and related \
rules together they can be applied to more complicated problems later.  \
Additional rules can be included as the need arises.\
\>", "Text"],

Cell[BoxData[
    \(\(dimrules = {Velocity \[Rule] Length\/Time, 
          Acceleration \[Rule] Velocity\/Time, 
          Force \[Rule] Mass\ Acceleration, Energy \[Rule] Force\ Length, 
          G \[Rule] Force\/\((Mass\^2/Length\^2)\), 
          c \[Rule] Velocity, \ \[HBar] \[Rule] Energy\ Time};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(g \[Equal] \(G\ M\)\/r\^2 /. {g \[Rule] Acceleration, M \[Rule] Mass, 
          r \[Rule] Length}\) //. dimrules\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Alternatively, suppose you know that some quantity must arise as a simple \
product of powers of fundamental constants.  For example, the mass scale for \
which quantum mechanics affects gravity must involve the fundamental \
parameter of quantum mechanics, \[HBar], the fundamental parameter of \
gravity, ",
  StyleBox["G",
    FontSlant->"Italic"],
  ", and the fundamental parameter of relativity, ",
  StyleBox["c",
    FontSlant->"Italic"],
  ".  The mass constructed from these fundamental constants is known as the ",
  
  StyleBox["Planck mass",
    FontSlant->"Italic"],
  ".  Similarly, these constants can also be used to define a Planck length \
and a Planck time because three constants that involve three physical \
dimensions can be combined to form three independent scales, one for each of \
the dimensions involved."
}], "Text"],

Cell["\<\
To determine the Planck scales, we combine these fundamental constants as a \
product with undetermined exponents\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(product = \(\[HBar]\^\[Alpha]\) \(G\^\[Beta]\) c\^\[Gamma] //. 
          dimrules // PowerExpand\)], "Input"],

Cell[BoxData[
    \(Length\^\(2\ \[Alpha] + 3\ \[Beta] + \[Gamma]\)\ Mass\^\(\[Alpha] - \
\[Beta]\)\ Time\^\(\(-\[Alpha]\) - 2\ \[Beta] - \[Gamma]\)\)], "Output"]
}, Closed]],

Cell["and then develop systems of equations", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(eqs = 
      product /. {\(Mass\^a_\) \(Length\^b_\) 
              Time\^c_ \[Rule] {{a \[Equal] 1, b \[Equal] 0, 
                c \[Equal] 0}, {a \[Equal] 0, b \[Equal] 1, 
                c \[Equal] 0}, {a \[Equal] 0, b \[Equal] 0, 
                c \[Equal] 1}}\ }\)], "Input"],

Cell[BoxData[
    \({{\[Alpha] - \[Beta] \[Equal] 1, 
        2\ \[Alpha] + 3\ \[Beta] + \[Gamma] \[Equal] 
          0, \(-\[Alpha]\) - 2\ \[Beta] - \[Gamma] \[Equal] 
          0}, {\[Alpha] - \[Beta] \[Equal] 0, 
        2\ \[Alpha] + 3\ \[Beta] + \[Gamma] \[Equal] 
          1, \(-\[Alpha]\) - 2\ \[Beta] - \[Gamma] \[Equal] 
          0}, {\[Alpha] - \[Beta] \[Equal] 0, 
        2\ \[Alpha] + 3\ \[Beta] + \[Gamma] \[Equal] 
          0, \(-\[Alpha]\) - 2\ \[Beta] - \[Gamma] \[Equal] 1}}\)], "Output"]
}, Closed]],

Cell["\<\
whose solutions give the combinations of exponents that yield quantities \
which depend upon a single physical dimension\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlanckScalesSymbolic = \({Planck[Mass], Planck[Length], 
          Planck[Time]} = \(\(\[HBar]\^\[Alpha]\) \(G\^\[Beta]\) c\^\[Gamma] /. 
                Solve[#, {\[Alpha], \[Beta], \[Gamma]}] &\)\  /@ \ eqs\  // 
          Flatten\)\)], "Input"],

Cell[BoxData[
    \({\(\@c\ \@\[HBar]\)\/\@G, \(\@G\ \@\[HBar]\)\/c\^\(3/2\), \(\@G\ \@\
\[HBar]\)\/c\^\(5/2\)}\)], "Output"]
}, Closed]],

Cell["\<\
You should check for yourself that these expressions do indeed yield unique \
mass, length, and time scales.\
\>", "Text"],

Cell[TextData[{
  "Evaluate the Planck temperature scale by including the Temperature \
dimension and the Boltzmann constant, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_B\)]],
  " with dimensions of Energy/Temperature, in the foregoing analysis. "
}], "Exercise"],

Cell[TextData[{
  "The oscillation period of a simple pendulum must depend upon its length \
\[ScriptL], mass ",
  StyleBox["m",
    FontSlant->"Italic"],
  ", and the gravitational acceleration, ",
  StyleBox["g",
    FontSlant->"Italic"],
  ".  Use dimensional analysis to determine how the period must scale with \
these parameters."
}], "Exercise"],

Cell[TextData[{
  "The vibrational frequency for a stretched string can depend upon its \
tension ",
  StyleBox["T",
    FontSlant->"Italic"],
  ", length \[ScriptL]",
  StyleBox[",",
    FontSlant->"Italic"],
  " and mass per unit length, \[Mu].  Use dimensional analysis to determine \
how the frequency must scale with these parameters.  Is this consistent with \
what you know about guitar strings?"
}], "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Units", "Section"],

Cell[CellGroupData[{

Cell["Standards", "Subsection"],

Cell[TextData[{
  "Even though we have already used the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages ",
  StyleBox["Miscellaneous`PhysicalConstants`", "InlineInput",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Miscellaneous`Units`", "InlineInput",
    FontWeight->"Bold"],
  " in the notebook ",
  ButtonBox["getting started",
    ButtonData:>{"Primary topics/getting started.nb", None},
    ButtonStyle->"Hyperlink"],
  ", it is worth reviewing the meaning of dimensions and units.  A quantity \
with dimensions, such as length or mass, can be assigned a numerical value \
only by comparison with an established standard of measurement.  For example, \
the primary standard of length used to be the separation between two lines \
inscribed upon a particular platinum-iridium bar maintained under carefully \
controlled conditions of temperature and humidity by the International Bureau \
of Weights and Measures in S\[EGrave]vres, France.  In principle, secondary \
standards would be manufactured by comparison with the primary standard and \
then length measurements would be made in various laboratories by reference \
to these secondary standards.  Although the standard of length was redefined \
in 1983 and is now based upon the speed of light and a standard of time \
derived from an atomic clock, the fundamental idea is that dimensioned \
quantities must always be measured relative to some physical standard which \
serves as the unit of measure.  Thus, the fact that my diminutive stature is \
1.42 times the standard unit of length is expressed as a height of 1.42 \
meters."
}], "Text"],

Cell[TextData[{
  "The definitions of measurement units are quite arbitrary, reflecting a \
long history of human quirks, and would be practically useless without \
international standardization.  Modern scientific measurements are based upon \
the Syst\[EGrave]me International d'Unit\[EAcute]s (International System of \
Units), known as SI units, maintained by an international committee.  The \
physical constants stored in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package ",
  StyleBox["Miscellaneous`PhysicalConstants`", "InlineInput",
    FontWeight->"Bold"],
  " are expressed in SI units.  The following command produces a list of the \
available constants. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Miscellaneous`PhysicalConstants`*\)\)], "Input"],

Cell[BoxData[GridBox[{
        {
          StyleBox["Miscellaneous`PhysicalConstants`",
            FontFamily->"Helvetica",
            FontSize->12,
            FontWeight->"Bold"]},
        {GridBox[{
              {
                ButtonBox[
                  StyleBox["AccelerationDueToGravity",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`\
AccelerationDueToGravity"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["ElectronGFactor",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`ElectronGFactor"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["MuonMagneticMoment",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`MuonMagneticMoment"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["SackurTetrodeConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`SackurTetrodeConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["AgeOfUniverse",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`AgeOfUniverse"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["ElectronMagneticMoment",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`ElectronMagneticMoment"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["MuonMass",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`MuonMass"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["SolarConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`SolarConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["AvogadroConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`AvogadroConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["ElectronMass",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`ElectronMass"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["NeutronComptonWavelength",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`\
NeutronComptonWavelength"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["SolarLuminosity",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`SolarLuminosity"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["BohrRadius",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`BohrRadius"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["FaradayConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`FaradayConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["NeutronMagneticMoment",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`NeutronMagneticMoment"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["SolarRadius",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`SolarRadius"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["BoltzmannConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`BoltzmannConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["FineStructureConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`FineStructureConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["NeutronMass",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`NeutronMass"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["SolarSchwarzschildRadius",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`\
SolarSchwarzschildRadius"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["ClassicalElectronRadius",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`ClassicalElectronRadius"}\
,
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["GalacticUnit",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`GalacticUnit"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["PlanckConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`PlanckConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["SpeedOfLight",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`SpeedOfLight"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["CosmicBackgroundTemperature",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`\
CosmicBackgroundTemperature"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["GravitationalConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`GravitationalConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["PlanckConstantReduced",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`PlanckConstantReduced"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["SpeedOfSound",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`SpeedOfSound"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["DeuteronMagneticMoment",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`DeuteronMagneticMoment"},
                  
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["HubbleConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`HubbleConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["PlanckMass",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`PlanckMass"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["StefanConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`StefanConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["DeuteronMass",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`DeuteronMass"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["IcePoint",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`IcePoint"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["ProtonComptonWavelength",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`ProtonComptonWavelength"}\
,
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["ThomsonCrossSection",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`ThomsonCrossSection"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["EarthMass",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`EarthMass"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["MagneticFluxQuantum",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`MagneticFluxQuantum"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["ProtonMagneticMoment",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`ProtonMagneticMoment"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["VacuumPermeability",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`VacuumPermeability"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["EarthRadius",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`EarthRadius"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["MolarGasConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`MolarGasConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["ProtonMass",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`ProtonMass"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["VacuumPermittivity",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`VacuumPermittivity"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["ElectronCharge",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`ElectronCharge"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["MolarVolume",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`MolarVolume"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["QuantizedHallConductance",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`\
QuantizedHallConductance"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["WeakMixingAngle",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`WeakMixingAngle"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"]},
              {
                ButtonBox[
                  StyleBox["ElectronComptonWavelength",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`\
ElectronComptonWavelength"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["MuonGFactor",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`MuonGFactor"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], 
                ButtonBox[
                  StyleBox["RydbergConstant",
                    "Hyperlink"],
                  
                  ButtonFunction:>(
                    Internal`PutInformation[ #, LongForm -> False]&),
                  ButtonEvaluator->Automatic,
                  
                  ButtonData:>{"Info3351098260-5063721", 
                    "Miscellaneous`PhysicalConstants`RydbergConstant"},
                  ButtonFrame->"None",
                  ButtonNote->"Miscellaneous`PhysicalConstants`"], ""}
              },
            RowMinHeight->{1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1.05}]}
        },
      RowSpacings->{2, 3},
      ColumnsEqual->True]], "Print",
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->RGBColor[0.964706, 0.929412, 0.839216],
  ButtonBoxOptions->{Active->True},
  GridBoxOptions->{ColumnAlignments->{Left}}]
}, Closed]],

Cell["For example, the gravitational constant is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GravitationalConstant\)], "Input"],

Cell[BoxData[
    \(\(6.673`*^-11\ Meter\^2\ Newton\)\/Kilogram\^2\)], "Output"]
}, Closed]],

Cell["\<\
If we now evaluate the Planck mass, length, and time using these constants\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlanckScalesNumeric = \(PlanckScalesSymbolic /. {\[HBar] \[Rule] 
                PlanckConstantReduced, G \[Rule] GravitationalConstant, 
              c \[Rule] SpeedOfLight} // PowerExpand\) // Simplify\)], "Input"],

Cell[BoxData[
    \({\(2.1766461050355274`*^-8\ \@Joule\ Kilogram\)\/\(\@Meter\ \@Newton\), \
\(1.6160974426112715`*^-35\ \@Joule\ \@Newton\ Second\^2\)\/\(Kilogram\ \
\@Meter\), \(5.390720811966763`*^-44\ \@Joule\ \@Newton\ \
Second\^3\)\/\(Kilogram\ Meter\^\(3/2\)\)}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "we obtain correct but unsightly expressions in which the derived units of \
force and energy are not simplified.  Unfortunately, the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages do not provide any method for simplifying expressions of this \
type, but we can easily write replacement rules which accomplish this task."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlanckScalesNumeric = \ 
      PlanckScalesNumeric //. {Joule \[Rule] Newton\ Meter, 
            Newton \[Rule] Kilogram\ Meter\ Second\^\(-2\)} // 
        PowerExpand\)], "Input"],

Cell[BoxData[
    \({2.1766461050355274`*^-8\ Kilogram, 1.6160974426112715`*^-35\ Meter, 
      5.390720811966763`*^-44\ Second}\)], "Output"]
}, Closed]],

Cell["\<\
Alternatively, if one agrees to express all physical quantities in SI units \
and knows that all relevant expressions are dimensionally consistent, then it \
is not necessary to carry the units in numerical calculations.  Each constant \
is represented in the form of a product that contains a numerical coefficient \
and a symbol representing the appropriate unit or combination of units.  For \
example, the full form of the gravitational constant is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[\ GravitationalConstant\ ]\)], "Input"],

Cell[BoxData[
    TagBox[
      StyleBox[\(Times[6.673`*^-11, Power[Kilogram, \(-2\)], Power[Meter, 2], 
          Newton]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output"]
}, Closed]],

Cell["\<\
The numerical value of a constant is then simply its first part\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(GravitationalConstant\[LeftDoubleBracket]1\[RightDoubleBracket]\)], \
"Input"],

Cell[BoxData[
    \(6.673`*^-11\)], "Output"]
}, Closed]],

Cell["Thus, we can obtain the Planck scales in SI units", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlanckScalesSymbolic /. {\[HBar] \[Rule] 
          PlanckConstantReduced\[LeftDoubleBracket]1\[RightDoubleBracket], 
        G \[Rule] 
          GravitationalConstant\[LeftDoubleBracket]1\[RightDoubleBracket], 
        c \[Rule] 
          SpeedOfLight\[LeftDoubleBracket]1\[RightDoubleBracket]}\)], "Input"],

Cell[BoxData[
    \({2.1766461050355274`*^-8, 1.6160974426112715`*^-35, 
      5.390720811966763`*^-44}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "without manipulating the units.  Actually, the ",
  StyleBox["PhysicalConstants", "InlineInput",
    FontWeight->"Bold"],
  " package provides a value for the Planck mass which agrees with our \
result."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlanckMass\)], "Input"],

Cell[BoxData[
    \(2.1767`*^-8\ Kilogram\)], "Output"]
}, Closed]],

Cell["\<\
This value for the Planck mass may seem to be quite small, but it is actually \
quite large compared with the masses of known elementary particles, such as \
the electron.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PlanckMass/ElectronMass\)], "Input"],

Cell[BoxData[
    \(2.3895144903069976`*^22\)], "Output"]
}, Closed]],

Cell["\<\
Compute the gravitational acceleration at the earth's surface using values \
for the mass and radius of the earth from PhysicalConstants.\
\>", "Exercise"]
}, Closed]],

Cell[CellGroupData[{

Cell["Conversions", "Subsection"],

Cell[TextData[{
  "Often one is presented with quantities expressed in British, engineering, \
or other units.  The command ",
  StyleBox["SI[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["quantity", "InlineInput"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " converts to SI units."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SI[Horsepower]\)], "Input"],

Cell[BoxData[
    \(745.7`\ Watt\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SI[Slug]\)], "Input"],

Cell[BoxData[
    \(14.5939`\ Kilogram\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SI[BTU]\)], "Input"],

Cell[BoxData[
    \(1055.0600000000002`\ Joule\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Convert\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"Convert[old, new] converts old to a form involving the \
combination of units new.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"Miscellaneous`Units`",
        Active->True,
        ButtonStyle->"AddOnsLink"]}]], "Print",
  CellTags->"Info3351098527-8632358"]
}, Closed]],

Cell[TextData[{
  "More generally, ",
  StyleBox["Convert[", "InlineInput",
    FontWeight->"Bold"],
  StyleBox["quantity,units", "InlineInput"],
  StyleBox["]", "InlineInput",
    FontWeight->"Bold"],
  " converts a ",
  StyleBox["quantity", "InlineInput"],
  " to a new set of dimensionally consistent ",
  StyleBox["units", "InlineInput"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Convert[0.5\ Acre, \ Meter\^2]\)], "Input"],

Cell[BoxData[
    \(2023.4282111999999`\ Meter\^2\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Convert[Parsec, LightYear]\)], "Input"],

Cell[BoxData[
    \(3.2615876364720267`\ LightYear\)], "Output"]
}, Closed]],

Cell[TextData[{
  StyleBox["Convert", "InlineInput",
    FontWeight->"Bold"],
  " simply multiplies by the appropriate scale factor, but for temperature \
there can be an offset in addition to a scale factor.  Therefore, for \
temperature it is better to use ",
  StyleBox["ConvertTemperature", "InlineInput",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?ConvertTem*\)\)], "Input"],

Cell[BoxData[
    RowBox[{"\<\"ConvertTemperature[temp, old, new] converts temp from the \
old scale to the new scale.\"\>", " ", 
      ButtonBox[
        StyleBox["More\[Ellipsis]",
          "SR"],
        ButtonData:>"Miscellaneous`Units`",
        Active->True,
        ButtonStyle->"AddOnsLink"]}]], "Print",
  CellTags->"Info3351098591-5019139"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ConvertTemperature[32. , \ Fahrenheit, Kelvin]\)], "Input"],

Cell[BoxData[
    \(273.15`\)], "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Difficulties with dimensioned quantities", "Section"],

Cell["\<\
If one attempts to write a function for the gravitational field of a uniform \
sphere using arguments which may have units (such as radius in meters and \
mass in kilograms), one is likely to encounter some difficulties that are \
instructive in themselves.  The first attempt made by many students looks \
something like this.\
\>", "Text"],

Cell[BoxData[{
    \(\(Clear[g, r, R, M, G];\)\), "\n", 
    \(\(g[r_\  /; r > R]\  := \ \ \(G\ M\)\/r\^2;\)\), "\n", 
    \(g[r_\  /; \ r \[LessEqual] R] := \(\(G\ M\)\/R\^3\) r\)}], "Input"],

Cell[TextData[{
  "However, there are two reasons that this approach does not work well.  \
First, because the condition applied to the lhs depends upon both ",
  StyleBox["r", "InlineInput",
    FontWeight->"Bold"],
  " and ",
  StyleBox["R", "InlineInput",
    FontWeight->"Bold"],
  ", the condition cannot be evaluated unless ",
  StyleBox["R", "InlineInput",
    FontWeight->"Bold"],
  " has a preset value ."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[g[r], {r, 0, 2, 0.5}]\)], "Input"],

Cell[BoxData[
    \({g[0], g[0.5`], g[1.`], g[1.5`], g[2.`]}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(R = 1;\)\), "\n", 
    \(Table[g[r], {r, 0, 2, 0.5}]\)}], "Input"],

Cell[BoxData[
    \({0, 0.5`\ G\ M, 1.`\ G\ M, 0.4444444444444444`\ G\ M, 
      0.25`\ G\ M}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Second, if the variables in the problem have dimensions the condition may \
not be evaluated correctly.  We will return to this difficulty again later, \
but for now consider the following attempt to produce symbolic values in \
terms of ",
  StyleBox["R", "InlineInput",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[R];\)\), "\n", 
    \(Table[g[r], {r, 0, 2\ R, 0.5\ R}]\)}], "Input"],

Cell[BoxData[
    \({g[0], g[0.5`\ R], g[1.`\ R], g[1.5`\ R], g[2.`\ R]}\)], "Output"]
}, Closed]],

Cell["\<\
The function remains unevaluated because the condition cannot be evaluated.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(0.5\ R \[LessEqual] R\)], "Input"],

Cell[BoxData[
    \(0.5`\ R \[LessEqual] R\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Why not \[LongDash] isn't it obvious that ",
  Cell[BoxData[
      \(TraditionalForm\`0.5\ R\)]],
  " is less than ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  "?  Actually, it is not obvious to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " because, without your intuition about the meaning of the symbols, it does \
not automatically assume that ",
  StyleBox["R",
    FontSlant->"Italic"],
  " is positive."
}], "Text"],

Cell[TextData[{
  "A better version of this function includes all variables as arguments.  We \
consider the radius and mass of the object to be variables because they \
depend upon the particular object under consideration, but we consider ",
  StyleBox["G", "InlineInput",
    FontWeight->"Bold"],
  " to be a parameter because it is a universal constant of nature.  \
Therefore, we include ",
  StyleBox["R", "InlineInput",
    FontWeight->"Bold"],
  " and ",
  StyleBox["M", "InlineInput",
    FontWeight->"Bold"],
  " as arguments but omit ",
  StyleBox["G", "InlineInput",
    FontWeight->"Bold"],
  ".  Because our conditions now depend upon two arguments, we must place the \
conditions on the rhs of the function definitions.  We also include a \
dimensionless form in which ",
  StyleBox["g", "InlineInput",
    FontWeight->"Bold"],
  " is expressed as a fraction of the surface gravity ",
  Cell[BoxData[
      \(TraditionalForm\`G\ M\ /R\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is measured relative to the surface radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Clear[g, r, R, M, G];\)\), "\n", 
    \(\(g[r_, R_, M_] := \ \(G\ M\)\/r\^2 /; r > R\ ;\)\), "\n", 
    \(\(g[r_, R_, M_] := \(\(G\ M\)\/R\^3\) r\  /; \ 
          r \[LessEqual] R\ ;\)\), "\n", 
    \(g[r_]\  := \ g[r, 1, 1] /. G \[Rule] 1\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[g[r], {r, 0, 3}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.589544 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13262 -18 -4.5 ]
[.01131 .13262 0 4.5 ]
[.01131 .25053 -18 -4.5 ]
[.01131 .25053 0 4.5 ]
[.01131 .36844 -18 -4.5 ]
[.01131 .36844 0 4.5 ]
[.01131 .48635 -18 -4.5 ]
[.01131 .48635 0 4.5 ]
[.01131 .60426 -6 -4.5 ]
[.01131 .60426 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13262 m
.03006 .13262 L
s
[(0.2)] .01131 .13262 1 0 Mshowa
.02381 .25053 m
.03006 .25053 L
s
[(0.4)] .01131 .25053 1 0 Mshowa
.02381 .36844 m
.03006 .36844 L
s
[(0.6)] .01131 .36844 1 0 Mshowa
.02381 .48635 m
.03006 .48635 L
s
[(0.8)] .01131 .48635 1 0 Mshowa
.02381 .60426 m
.03006 .60426 L
s
[(1)] .01131 .60426 1 0 Mshowa
.125 Mabswid
.02381 .04419 m
.02756 .04419 L
s
.02381 .07367 m
.02756 .07367 L
s
.02381 .10315 m
.02756 .10315 L
s
.02381 .1621 m
.02756 .1621 L
s
.02381 .19158 m
.02756 .19158 L
s
.02381 .22106 m
.02756 .22106 L
s
.02381 .28001 m
.02756 .28001 L
s
.02381 .30949 m
.02756 .30949 L
s
.02381 .33896 m
.02756 .33896 L
s
.02381 .39792 m
.02756 .39792 L
s
.02381 .4274 m
.02756 .4274 L
s
.02381 .45687 m
.02756 .45687 L
s
.02381 .51583 m
.02756 .51583 L
s
.02381 .54531 m
.02756 .54531 L
s
.02381 .57478 m
.02756 .57478 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .08646 L
.10458 .16471 L
.14415 .2382 L
.18221 .30887 L
.22272 .3841 L
.26171 .45651 L
.30316 .53348 L
.32392 .57203 L
.33304 .58897 L
.33554 .59361 L
.33823 .59861 L
.33953 .60102 L
.34076 .60332 L
.34187 .60202 L
.34309 .59757 L
.36173 .53503 L
.3815 .47911 L
.42214 .38917 L
.46127 .32518 L
.50286 .27362 L
.54292 .2352 L
.58147 .20577 L
.62248 .18049 L
.66196 .16061 L
.69994 .14468 L
.74036 .13043 L
.77927 .11882 L
.82063 .10829 L
.86048 .09959 L
.8988 .09232 L
.93959 .08556 L
.97619 .08022 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00E@3oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01@3oool0
1@2oM0000000000000000000M;oo0380oooo00<0okmd0000000000000`0000000`00M;l0oooo0?oo
o`0_0?ooo`030?noM0000000000000<0000000<007Bo0?ooo`3oool00P3oool00`2oM0000000001d
_`050?ooo`050;md0000000000000000001d_ol0<03oool00`3ookl0M000000000040000000307Bo
o`3oool0oooo02h0oooo00<0oono07@000000000100000000`1d_ol0oooo0?ooo`020?ooo`030;md
0000000007Bo00D0oooo00D0_g@0000000000000000007Boo`0c0?ooo`050;md0000000000000000
0018W=l02@3oool005D0oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md00000000
07Bo00@0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo03@0oooo00<0W4Q809cOo`3oool0
=@3oool00`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo00@0oooo00L0_g@0001d_`3oool0
oooo0?oOW0180000M;oo0300oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`0`0?oo
o`030;md000007@0_ooo0080oooo00<0giad09cOo`3oool00`3oool00`2oM0000000001d_`040?oo
o`070;md0000M;l0oooo0?ooo`3ogi`0B00007Boo`0a0?ooo`070;md0000M;l0oooo0?ooo`3ookl0
M00004RLg`080?ooo`00E03oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo00l0oooo
00<0okmd001d_`3oool0<`3oool00`2LB4P0W=oo0?ooo`0e0?ooo`0309a8B02Lgol0oooo0140oooo
00<0okmd001d_`3oool0<03oool00`3o_g@0001809cOo`0e0?ooo`030?noM00004P0W=oo01<0oooo
00<0okmd001d_`3oool0=@3oool00`3o_g@007Bo0?ooo`070?ooo`00E03oool00`3OW4P0B9cO0?oo
o`020?ooo`030?noM000M;l0oooo00l0oooo00<0okmd001d_`3oool0<`3oool00`2LB4P0W=oo0?oo
o`0e0?ooo`0309a8B02Lgol0oooo0140oooo00<0okmd001d_`3oool0<@3oool00`3ogi`0B00004RL
g`0e0?ooo`030?oOW0180000B9cO0180oooo00<0okmd001d_`3oool0=03oool00`3ogi`0B01809cO
o`080?ooo`00E03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0W4P0
07Boo`3oool0<`3oool00`2LB4P0W=oo0?ooo`0e0?ooo`0309a8B02Lgol0oooo0140oooo00<0W4P0
07Boo`3oool0<`3oool00`2LB000B9cO0?ooo`0e0?ooo`0309a80018W=l0oooo0100oooo00<0W4P0
07Boo`3oool0<P3oool0103OW4P000000000B02Lgol90?ooo`00E03oool00`3OW4P0B9cO0?ooo`02
0?ooo`030?noM000M;l0oooo00X0oooo00<0oono07@0000000000P0000000`18W=l0oooo0?ooo`0c
0?ooo`0309a8B02Lgol0oooo03D0oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M00000000002
0000000304RLg`3oool0oooo03@0oooo00<0W4Qd0;ooo`3oool0=@3oool00`2LB7@0_ooo0?ooo`0:
0?ooo`030?oo_`1d000000000080000000<0B9cO0?ooo`3oool0=03oool00`3ogi`0B01809cOo`08
0?ooo`00E03oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00X0oooo00<0oono07@0
M02oool0>03oool00`2LB4P0W=oo0?ooo`0e0?ooo`0309a8B02Lgol0oooo00`0oooo00<0oono07@0
M02oool0=03oool00`3OW4P0M;oo0?ooo`020?ooo`030;md001d_ol0oooo0300oooo00<0gia807Bo
o`3oool00P3oool00`2oM000M;oo0?ooo`0:0?ooo`030?oo_`1d07@0_ooo03X0oooo00<0_g@007Bo
o`3oool01`3oool005D0oooo00H0W4P007Boo`3oool0omnL04P0M02oool;0?ooo`030?oo_`1d07@0
_ooo03D0oooo00D0gia800000000B9`0W4Q809cOo`0c0?ooo`050=nLB000000004RL09a8B02Lgol0
3@3oool00`3ookl0M01d0;ooo`0d0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`0a0?oo
o`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`0;0?ooo`030?oo_`1d07@0_ooo03D0oooo00L0
okmd0000B02Lgol0oooo0?oOW01804P0W=oo00P0oooo001E0?ooo`050?oo_`1d000000000000B02L
gol0303oool00`3ookl0M00000000002000000030000M02oool0oooo0380oooo00<0gia80000B02L
gol0=@3oool00`3OW4P0001809cOo`0=0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3o
ool0<03oool01@3o_g@000000000000004P0W=oo03<0oooo00D0okmd000000000000001809cOo`0<
0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool0<@3oool01@3ogi`0B00000000000
0000M;oo00T0oooo003o0?oook40oooo003o0?oook40oooo000P0?ooo`030000003oool0oooo0?l0
ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?oo
o`3o0?ooohh0oooo000P0?ooo`030000003oool0oooo0?l0ooooSP3oool00200oooo00<000000?oo
o`3oool0o`3ooon>0?ooo`00803oool00`000000oooo0?ooo`3o0?ooohh0oooo000F0?ooool00000
VP0000010?ooo`00803oool2000000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00T0oooo000P0?ooo`8000002`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00200oooo00<000000?oo
o`000000?P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool02@3oool00200oooo00<000000?ooo`000000o`3ooon>0?ooo`00803oool010000000oooo
0?ooo`00003o0?ooohd0oooo000P0?ooo`040000003oool0oooo00000?l0ooooS@3oool00200oooo
00D000000?ooo`3oool0oooo0000003o0?oooh`0oooo000P0?ooo`050000003oool0oooo0?ooo`00
0000o`3ooon<0?ooo`00803oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo
R@3oool00200oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooohP0oooo000P
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooon80?ooo`00803oool20000
00D0oooo00<000000?ooo`3oool0o`3ooon70?ooo`00803oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0?l0ooooQ`3oool00200oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3o0?ooohH0oooo000P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3o
oon60?ooo`00803oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooQ@3oool0
0200oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooohD0oooo000P0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooon40?ooo`00803oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0?l0ooooQ03oool00200oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`3o0?oooh<0oooo000P0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0o`3ooon20?ooo`00803oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0?l0ooooPP3oool00200oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?oooh40
oooo000P0?ooo`8000002`3oool00`000000oooo0?ooo`3o0?oooh40oooo000P0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0o`3ooon00?ooo`00803oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0?l0ooooP03oool00200oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`3o0?ooog00oooo1000000;0?ooo`00803oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0?l0ooooJ@3oool7000000l0oooo000P0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0o`3ooomR0?ooo`H000005P3oool00200oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`3o0?oooe/0oooo1P00000L0?ooo`00803oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0?l0ooooE@3oool600000280oooo000P0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0o`3ooom?0?ooo`D00000:03oool00200oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`3o0?ooodX0oooo1@00000]0?ooo`00803oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0?l0oooo@`3oool600000380oooo000P0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0o`3oooln0?ooo`D00000>03oool00200oooo0P00000B
0?ooo`030000003oool0oooo0?l0oooo>03oool5000003d0oooo000P0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0o`3ooolb0?ooo`H00000@P3oool00200oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`3o0?ooobd0oooo100000180?ooo`00803oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo:@3oool4000004`0oooo000P0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0o`3ooolU0?ooo`<00000D03oool00200oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooob80oooo0`00001C0?ooo`00803oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo7@3oool4000005H0oooo000P0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`<00000FP3oool00200oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`3o0?oooaD0oooo1000001M0?ooo`000P3o
ool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l00`3oool00`3ookl0M000
000000040000000307Boo`3oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`3o0?oooa40oooo1000001Q0?ooo`000P3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0
oooo00<0_g@000000000M;l0103oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo00D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooo``0oooo1000001U0?ooo`00
00<0oooo0?noM000M;l00`3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?noM00004P0W=oo00T0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo1000001Y0?ooo`0000<0
oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0<0?ooo`030?oOW0180000B9cO00P0oooo0`00
000G0?ooo`030000003oool0oooo0?l0oooo1@3oool2000006d0oooo00000`3oool0gia804RLg`03
0?ooo`030?noM000M;l0oooo00h0oooo00<0W4P004RLg`3oool01P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0?l0oooo0@3oool3000006l0oooo00000`3oool0gia804RLg`030?oo
o`030?noM000M;l0oooo00l0oooo00<0W4Qd0;ooo`3oool01@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0?d0oooo0`00001b0?ooo`0000<0oooo0?noM018W=l00`3oool00`3OW4P0
B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3oool01@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0?X0oooo0P00001e0?ooo`000P3oool01P2LB000M;oo
0?ooo`3ogi`0B01d0;ooo`/0oooo00L0okmd0000M02oool0oooo0?noM00004P0W=oo00H0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`3g0?ooo`<00000M`3oool00080oooo00D0oono
07@000000000001809cOo`0=0?ooo`050?noM000000000000000B02Lgol01`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0?<0oooo0`00001j0?ooo`00803oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo0?40oooo0P00001m0?ooo`00803oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo0>h0oooo0P00001o0?ooo`00803oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0>`0oooo0P0000210?ooo`00803oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0>P0oooo0`0000230?ooo`00803oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0>H0oooo0P0000260?ooo`00803oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo0><0oooo0P0000280?ooo`00803oool2000001h0oooo00<000000?ooo`3oool0h@3oool2
000008X0oooo000P0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0gP3oool20000
08`0oooo000P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0f`3oool2000008h0
oooo000P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0f@3oool200000900oooo
000P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0eP3oool200000980oooo000P
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0e03oool2000009@0oooo000P0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0d@3oool2000009H0oooo000P0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0c`3oool2000009P0oooo000P0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0c03oool2000009X0oooo000P0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0bP3oool2000009`0oooo000P0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0a`3oool2000009h0oooo000P0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`2N0?ooo`00803oool2000002D0
oooo00<000000?ooo`3oool0``3oool200000:40oooo000P0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0`@3oool200000:<0oooo000P0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0_P3oool200000:D0oooo000P0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`2U0?ooo`00803oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0;X0oooo0P00002X0?ooo`00803oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0;L0oooo0P00002Z0?ooo`00803oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo0;H0oooo00<000000?ooo`3oool0ZP3oool00200oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo0:/0oooo000P0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool0/P3oool200000:h0oooo000P0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`2^0?ooo`00803oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0[`3oool00200oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0;00oooo
000P0?ooo`800000:`3oool00`000000oooo0?ooo`2[0?ooo`800000/`3oool00200oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0;<0oooo000P0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`2d0?oo
o`00803oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool0]@3oool00200oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2T0?ooo`800000
^03oool00200oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2R0?ooo`030000003o
ool0oooo0;P0oooo000P0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0X@3oool0
0`000000oooo0?ooo`2i0?ooo`00803oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0^P3oool00200oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`2M0?ooo`030000003oool0oooo0;/0oooo00020?ooo`050?noM000000000000000001d
_ol01@3oool00`2oM0000000001d_`060?ooo`050?oOW018000000000000001d_ol01P3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0_03oool00080
oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00P0oooo00<0_g@0
07Boo`3oool01P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo09X0oooo00<00000
0?ooo`3oool0_@3oool000030?ooo`3o_g@007Bo00<0oooo00<0gia804RLg`3oool03P3oool00`2o
M000M;oo0?ooo`060?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0V@3oool00`00
0000oooo0?ooo`2n0?ooo`0000<0oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0:0?ooo`03
0=nLB0000000000000<0000000<0M;oo0?ooo`3oool0103oool300000340oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`2o0?ooo`0000<0oooo0=nLB018W=l00`3oool00`3o_g@007Bo
0?ooo`0:0?ooo`060?noM00007@0_ooo0?ooo`2oM000M;oo1`3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo09H0oooo00<000000?ooo`3oool0`03oool000030?ooo`3OW4P0B9cO00<0
oooo00<0okmd001d_`3oool02`3oool01@3OW4P007Bo0?ooo`2oM000M;oo00L0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`2C0?ooo`800000``3oool000030?ooo`3o_g@0B9cO00<0
oooo00<0gia804RLg`3oool0303oool0102LB000B9cO0;md001d_ol70?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`330?ooo`000P3oool01P2LB000
M;oo0?ooo`3ogi`0B01d0;ooo`d0oooo00@0omnL04P0B018B000M;oo1`3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0a03oool00080oooo00D0oono
07@000000000001809cOo`0?0?ooo`030?noM0000000M;oo00L0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0<D0oooo000P0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`360?ooo`00803oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0a`3oool00200
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0<P0
oooo000P0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`390?ooo`00803oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0bP3oool00200oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo0</0oooo000P0?ooo`800000>03oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo0<`0oooo000P0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`3<0?ooo`00803oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo0880oooo00<000000?ooo`3oool0c@3oool00200oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0<h0oooo000P0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`3?0?ooo`00803oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0d03oool00200
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0=00
oooo000P0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0N`3oool00`000000oooo
0?ooo`3A0?ooo`00803oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0dP3oool00200oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo0=<0oooo000P0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`3D0?ooo`00803oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo07D0oooo00<000000?ooo`3oool0e@3oool00200oooo0P00000o0?ooo`030000
003oool0oooo07@0oooo00<000000?ooo`3oool0e@3oool00200oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0=H0oooo000P0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`3G0?ooo`00803oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0f03oool00200
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0=T0
oooo000P0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0K@3oool00`000000oooo
0?ooo`3I0?ooo`00803oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo06`0oooo00<0
00000?ooo`3oool0fP3oool00200oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo0=/0oooo000P0?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`3L0?ooo`00803oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool0g03oool00200oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0=d0oooo000P0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`3M0?ooo`00803oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0gP3oool0
0200oooo0P0000160?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0g`3oool00200
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0=l0
oooo000P0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`3P0?ooo`00803oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0h@3oool00200oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1O
0?ooo`030000003oool0oooo0>40oooo000P0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`3R0?ooo`00803oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo05d0oooo00<000000?ooo`3oool0hP3oool00200oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo0><0oooo00020?ooo`050?noM000
000000000000001d_ol01@3oool00`2oM0000000001d_`060?ooo`050;md0000000000000000M02o
ool01P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0i03oool00080oooo00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo
00D0oooo00H0gia8001d_`3oool0oooo0?noM000M;l60?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`3T0?ooo`0000<0oooo0?noM000M;l00`3oool0
0`3OW4P0B9cO0?ooo`0:0?ooo`030?oo_`1d0000M;oo0080oooo00<0oono07A8W03oool01@3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0i@3oool0
00030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool02P3oool01`3o_g@004Q807@0M02oool0
oooo0=nLB000M;l01P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0i@3oool000030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool02P3oool0
0`3ogi`0B4RL0?noM002000000030018W03oool0oooo00D0oooo0`00001;0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool0iP3oool000030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d
_`3oool02P3oool00`3ookl0M01d0;ooo`0:0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`3W0?ooo`0000<0oooo0?noM018W=l00`3oool00`3OW4P0
B9cO0?ooo`0;0?ooo`030;md0018W=l0oooo00T0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0>L0oooo00020?ooo`0609a8001d_ol0oooo0?oOW018
07@0_ooo303oool00`3ookl0M000001d_`090?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`3X0?ooo`000P3oool01@3ookl0M0000000000004P0W=oo
00l0oooo00@0_g@000000000000004RL1P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool0j@3oool00200oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0>T0oooo000P0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3Z0?ooo`00803oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0jP3oool00200oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0>/0oooo000P
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`3[
0?ooo`00803oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0k03oool00200oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0>`0oooo000P0?ooo`800000DP3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo0>d0oooo000P0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`3]0?ooo`00803oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0kP3oool00200oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo0>h0oooo000P0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`3^0?ooo`00803oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0k`3oool00200oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0>l0oooo000P
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3`
0?ooo`00803oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0l03oool00200oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo0?40oooo000P0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`3a0?ooo`00803oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0l@3oool00200oooo0P00001I0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool0lP3oool00200oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo0?80oooo000P0?ooo`030000003oool0oooo05T0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`3c0?ooo`00803oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0l`3oool00200oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0?@0oooo000P
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`3d
0?ooo`00803oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0m@3oool00200oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo0?D0oooo000P0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`3e0?ooo`00803oool00`000000oooo0?ooo`1M0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool0mP3oool00200oooo00<000000?ooo`3oool0G@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?H0oooo000P0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`3g0?ooo`00803oool200000600
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`3g0?ooo`00803oool00`000000oooo
0?ooo`1O0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0n03oool00200oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0?P0oooo000P
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3h
0?ooo`00803oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0n@3oool00200oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0?T0oooo000P0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`3j0?ooo`00803oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool0nP3oool00080oooo00D0okmd000000000000000007Bo
o`050?ooo`030;md0000000007Bo00D0oooo00D0_g@00000000000000000001d_`070?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3k0?ooo`000P3o
ool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000M;l0103oool00`3o_g@0
07Bo0?ooo`020?ooo`030;mdB02Lgol0oooo00D0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo0?/0oooo00000`3oool0okmd001d_`030?ooo`030=nL
B018W=l0oooo00X0oooo00<0gia804RLg`3oool00P3oool00`2oM000M;oo0?ooo`050?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3k0?ooo`0000<0
oooo0=nLB018W=l00`3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?noM000B9`0oooo0080oooo00<0
W4Q809cOo`3oool01@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0o03oool000030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool02`3oool0
1@3OW4P00000000000000000B9cO00L0oooo0`00001U0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0o03oool000030?ooo`3OW4P0B9cO00<0oooo00<0okmd001d_`3oool02P3oool0
0`3ookl0M4RL0?ooo`020?ooo`0309a8M02oool0oooo00D0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0?`0oooo00000`3oool0okmd04RLg`030?oo
o`030=nLB018W=l0oooo00X0oooo00<0okmd04RLg`3oool00P3oool00`2oM000M;oo0?ooo`050?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3m0?oo
o`000P3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00L0omnL04P0M02oool0oooo0?oO
W01807@0_ooo00H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo0?d0oooo00020?ooo`050?oo_`1d000000000000B02Lgol03@3oool01@3o_g@00000
0000000004P0W=oo00L0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo0?d0oooo000P0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`3n0?ooo`00803oool00`000000oooo0?ooo`1X0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool0oP3oool00200oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?h0oooo000P0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`3o0?ooo`00803oool00`000000
oooo0?ooo`1Z0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0o`3oool00200oooo
00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0?l0oooo
0@3oool00200oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0?l0oooo0@3oool00200oooo0P00001/0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0o`3oool10?ooo`00803oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0o`3oool20?ooo`00803oool00`000000oooo0?ooo`1/0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3oool20?ooo`00803oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3oool20?ooo`00803o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3o
ool30?ooo`00803oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0o`3oool30?ooo`00803oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0o`3oool30?ooo`00803oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3oool40?ooo`00803oool00`000000oooo
0?ooo`1_0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0o`3oool40?ooo`00803o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3o
ool40?ooo`00803oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0o`3oool50?ooo`00803oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0o`3oool50?ooo`00803oool200000780oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`3o0?ooo`D0oooo000P0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooo`H0oooo000P0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3o0?ooo`H0oooo000P
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o
0?ooo`H0oooo000P0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`3o0?ooo`L0oooo000P0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo000P0?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooo`L0oooo000P0?ooo`030000003o
ool0oooo07D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000P
0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o
0?ooo`P0oooo000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`3o0?ooo`P0oooo000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?ooo`P0oooo000P0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooo`T0oooo000P0?ooo`800000N@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo2@3oool00200oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo2@3oool0
0200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0?l0oooo2P3oool00200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0?l0oooo2P3oool00200oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0?l0oooo2P3oool00200oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo2`3oool00200oooo00<00000
0?ooo`3oool0N`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo2`3oool0
0200oooo00<000000?ooo`3oool0O03oool01@000000oooo0?ooo`3oool000000?l0oooo3@3oool0
01<0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`040?ooo`030000003oool0oooo
07`0oooo00@000000?ooo`3oool00000o`3oool>0?ooo`005P3oool00`2LB4P0W=oo0?ooo`070?oo
o`030000003oool0oooo07d0oooo00<000000?ooo`000000o`3oool>0?ooo`005P3oool00`2LB4P0
W=oo0?ooo`070?ooo`030000003oool0oooo07h0oooo0P00003o0?ooo`h0oooo000F0?ooo`0309a8
B02Lgol0oooo00L0oooo00<000000?ooo`3oool0OP3oool200000?l0oooo3P3oool001H0oooo00<0
W4Q809cOo`3oool01`3oool300000?l0ooooSP3oool001H0oooo00<0W4Q809cOo`3oool01`3oool0
0`000000oooo0?ooo`3o0?ooohh0oooo000F0?ooo`0309a8B02Lgol0oooo00L0oooo00<000000?oo
o`3oool0o`3ooon>0?ooo`004`3oool01@3OW4P000000018W02LB4P0W=oo00P0oooo00<000000?oo
o`3oool0o`3ooon>0?ooo`005@3oool00`3OW4P0001809cOo`080?ooo`030000003oool0oooo0?l0
ooooSP3oool00200oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00o`3ooona0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-0.250272, -0.077327, \
0.0115814, 0.00623637}}]
}, Closed]],

Cell["\<\
However, this does not solve our difficulties for dimensioned quantities.  To \
be more specific, let us use parameters for the earth.  The obvious way to \
compute the surface gravity would be to assign values to the variables that \
include the units.\
\>", "Text"],

Cell[BoxData[
    \(\(earthParameters = {G \[Rule] GravitationalConstant, 
          R \[Rule] EarthRadius, M \[Rule] EarthMass};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[R, R, M] /. earthParameters\)], "Input"],

Cell[BoxData[
    \(g[6378140\ Meter, 6378140\ Meter, 5.9742`*^24\ Kilogram]\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Unfortunately, the obvious approach fails!  It is instructive to use ",
  StyleBox["Trace", "InlineInput",
    FontWeight->"Bold"],
  " to investigate the problem."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[R, R, M] /. earthParameters\  // Trace\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            TagBox[\(g[R, R, M]\),
              HoldForm], ",", 
            RowBox[{"{", 
              RowBox[{
                
                TagBox[\(RuleCondition[$ConditionHold[$ConditionHold[\(G\ M\)\
\/R\^2]], R > R]\),
                  HoldForm], ",", 
                TagBox["Fail",
                  HoldForm]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{
                
                TagBox[\(RuleCondition[$ConditionHold[$ConditionHold[\(\((G\ \
M)\)\ R\)\/R\^3]], R \[LessEqual] R]\),
                  HoldForm], ",", 
                TagBox["Fail",
                  HoldForm]}], "}"}], ",", 
            TagBox[\(g[R, R, M]\),
              HoldForm]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            TagBox["earthParameters",
              HoldForm], ",", 
            
            TagBox[\({G \[Rule] \(6.673`*^-11\ Meter\^2\ \
Newton\)\/Kilogram\^2, R \[Rule] 6378140\ Meter, 
                M \[Rule] 5.9742`*^24\ Kilogram}\),
              HoldForm]}], "}"}], ",", 
        TagBox[\(g[R, R, 
              M] /. \[InvisibleSpace]{G \[Rule] \(6.673`*^-11\ Meter\^2\ \
Newton\)\/Kilogram\^2, R \[Rule] 6378140\ Meter, 
              M \[Rule] 5.9742`*^24\ Kilogram}\),
          HoldForm], ",", 
        TagBox[\(g[6378140\ Meter, 6378140\ Meter, 5.9742`*^24\ Kilogram]\),
          HoldForm], ",", 
        RowBox[{"{", 
          RowBox[{
            
            TagBox[\(RuleCondition[$ConditionHold[$ConditionHold[\(G\ \
\((5.9742`*^24\ Kilogram)\)\)\/\((6378140\ Meter)\)\^2]], 
                6378140\ Meter > 6378140\ Meter]\),
              HoldForm], ",", 
            TagBox["Fail",
              HoldForm]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            
            TagBox[\(RuleCondition[$ConditionHold[$ConditionHold[\(\((G\ \
\((5.9742`*^24\ Kilogram)\))\)\ \((6378140\ Meter)\)\)\/\((6378140\ \
Meter)\)\^3]], 6378140\ Meter \[LessEqual] 6378140\ Meter]\),
              HoldForm], ",", 
            TagBox["Fail",
              HoldForm]}], "}"}], ",", 
        TagBox[\(g[6378140\ Meter, 6378140\ Meter, 5.9742`*^24\ Kilogram]\),
          HoldForm]}], "}"}]], "Output"]
}, Closed]],

Cell["\<\
Although the output it fairly cryptic, one soon discovers that our \
difficulties are related to the failure to properly evaluate the following \
condition.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EarthRadius\  \[LessEqual] EarthRadius\)], "Input"],

Cell[BoxData[
    \(6378140\ Meter \[LessEqual] 6378140\ Meter\)], "Output"]
}, Closed]],

Cell[TextData[{
  "How can this fail?  We can understand that the failure to evaluate ",
  StyleBox["0.5 R \[LessEqual] R ", "InlineInput",
    FontWeight->"Bold"],
  "is to due the program's reluctance to make assumptions about positivity, \
and we can even forgive the failure to evaluate"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(0.5\ Meter\  \[LessEqual] \ Meter\)], "Input"],

Cell[BoxData[
    \(0.5`\ Meter \[LessEqual] Meter\)], "Output"]
}, Closed]],

Cell[TextData[{
  "properly even though ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " really should know that standard units can be treated as positive \
quantities, but the failure to evaluate"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[a];\)\), "\n", 
    \(a\  \[LessEqual] a\)}], "Input"],

Cell[BoxData[
    \(a \[LessEqual] a\)], "Output"]
}, Closed]],

Cell[TextData[{
  "as ",
  StyleBox["True", "InlineInput"],
  " strikes me as a shortcoming.  Evidently, the ",
  StyleBox["LessEqual", "InlineInput",
    FontWeight->"Bold"],
  " function requires numeric input and does not recognize the fact \"a \
symbol is identical to itself\" as an instance of equality between \
expressions."
}], "Text"],

Cell[TextData[{
  "Provided that we always express physical parameters in a consistent system \
of units and consider only dimensionally consistent expression, we can employ \
numerical values without units.  Thus, we can obtain the SI values for earth \
parameters by using ",
  StyleBox["Part", "InlineInput",
    FontWeight->"Bold"],
  " specifications as follows."
}], "Text"],

Cell[BoxData[
    \(\(earthParameters = {G \[Rule] 
            GravitationalConstant\[LeftDoubleBracket]1\[RightDoubleBracket], 
          R \[Rule] EarthRadius\[LeftDoubleBracket]1\[RightDoubleBracket], 
          M \[Rule] 
            EarthMass\[LeftDoubleBracket]1\[RightDoubleBracket]};\)\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(g[R, R, M] //. earthParameters\)], "Input"],

Cell[BoxData[
    \(9.799700137089136`\)], "Output"]
}, Closed]],

Cell[TextData[{
  "This value is expressed with respect to the SI unit of acceleration, \
namely ",
  Cell[BoxData[
      \(TraditionalForm\`m/s\^2\)]],
  ".  Although we consider the dimensionless version to be more informative, \
we can now plot the gravitational acceleration for this model of the earth \
using SI units."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
        g[r, R, M] //. earthParameters, \ {r, 0, \ 
          3\ EarthRadius\[LeftDoubleBracket]1\[RightDoubleBracket]}, 
        AxesLabel \[Rule] {"\<r   [m]\>", \*"\"\<g  \
[m/\!\(s\^2\)]\>\""}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 4.97732e-008 0.0147151 0.0601594 [
[.27268 .00222 -14.25 -12.5 ]
[.27268 .00222 14.25 0 ]
[.52154 .00222 -14.25 -12.5 ]
[.52154 .00222 14.25 0 ]
[.77041 .00222 -20.25 -12.5 ]
[.77041 .00222 20.25 0 ]
[1.025 .01472 0 -6.28125 ]
[1.025 .01472 46 6.28125 ]
[.01131 .13503 -6 -4.5 ]
[.01131 .13503 0 4.5 ]
[.01131 .25535 -6 -4.5 ]
[.01131 .25535 0 4.5 ]
[.01131 .37567 -6 -4.5 ]
[.01131 .37567 0 4.5 ]
[.01131 .49599 -6 -4.5 ]
[.01131 .49599 0 4.5 ]
[.01131 .61631 -12 -4.5 ]
[.01131 .61631 0 4.5 ]
[.02381 .64303 -28.3438 0 ]
[.02381 .64303 28.3438 12.9375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27268 .01472 m
.27268 .02097 L
s
gsave
.27268 .00222 -14.25 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.52154 .01472 m
.52154 .02097 L
s
gsave
.52154 .00222 -14.25 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(7) show
grestore
.77041 .01472 m
.77041 .02097 L
s
gsave
.77041 .00222 -20.25 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(7) show
grestore
.125 Mabswid
.07358 .01472 m
.07358 .01847 L
s
.12336 .01472 m
.12336 .01847 L
s
.17313 .01472 m
.17313 .01847 L
s
.2229 .01472 m
.2229 .01847 L
s
.32245 .01472 m
.32245 .01847 L
s
.37222 .01472 m
.37222 .01847 L
s
.42199 .01472 m
.42199 .01847 L
s
.47177 .01472 m
.47177 .01847 L
s
.57131 .01472 m
.57131 .01847 L
s
.62109 .01472 m
.62109 .01847 L
s
.67086 .01472 m
.67086 .01847 L
s
.72063 .01472 m
.72063 .01847 L
s
.82018 .01472 m
.82018 .01847 L
s
.86995 .01472 m
.86995 .01847 L
s
.91973 .01472 m
.91973 .01847 L
s
.9695 .01472 m
.9695 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 12.813 moveto
(@) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 12.813 moveto
(D) show
105.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13503 m
.03006 .13503 L
s
[(2)] .01131 .13503 1 0 Mshowa
.02381 .25535 m
.03006 .25535 L
s
[(4)] .01131 .25535 1 0 Mshowa
.02381 .37567 m
.03006 .37567 L
s
[(6)] .01131 .37567 1 0 Mshowa
.02381 .49599 m
.03006 .49599 L
s
[(8)] .01131 .49599 1 0 Mshowa
.02381 .61631 m
.03006 .61631 L
s
[(10)] .01131 .61631 1 0 Mshowa
.125 Mabswid
.02381 .04479 m
.02756 .04479 L
s
.02381 .07487 m
.02756 .07487 L
s
.02381 .10495 m
.02756 .10495 L
s
.02381 .16511 m
.02756 .16511 L
s
.02381 .19519 m
.02756 .19519 L
s
.02381 .22527 m
.02756 .22527 L
s
.02381 .28543 m
.02756 .28543 L
s
.02381 .31551 m
.02756 .31551 L
s
.02381 .34559 m
.02756 .34559 L
s
.02381 .40575 m
.02756 .40575 L
s
.02381 .43583 m
.02756 .43583 L
s
.02381 .46591 m
.02756 .46591 L
s
.02381 .52607 m
.02756 .52607 L
s
.02381 .55615 m
.02756 .55615 L
s
.02381 .58623 m
.02756 .58623 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -89.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.188 moveto
(@) show
87.000 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.188 moveto
(\\220) show
99.000 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(s) show
105.000 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
109.688 13.188 moveto
(D) show
115.688 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .08646 L
.10458 .16471 L
.14415 .2382 L
.18221 .30887 L
.22272 .3841 L
.26171 .45651 L
.30316 .53348 L
.32392 .57203 L
.33304 .58897 L
.33554 .59361 L
.33823 .59861 L
.33953 .60102 L
.34076 .60332 L
.34187 .60202 L
.34309 .59757 L
.36173 .53503 L
.3815 .47911 L
.42214 .38917 L
.46127 .32518 L
.50286 .27362 L
.54292 .2352 L
.58147 .20577 L
.62248 .18049 L
.66196 .16061 L
.69994 .14468 L
.74036 .13043 L
.77927 .11882 L
.82063 .10829 L
.86048 .09959 L
.8988 .09232 L
.93959 .08556 L
.97619 .08022 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00IP3oool0
1@2oM0000000000000000000M;oo00<0oooo00<0_gA809cOo`3oool00P3oool00`3o_eL000000000
000300000005001d_`3oool0oooo0?ooo`3o_g@00`0000000`1d_ol0oooo0?ooo`0`0?ooo`030?no
M0000000000000<0000000D007Bo0?ooo`3oool0_gA809cOo`030?ooo`030?noE`000000000000<0
000000D007Bo0?ooo`3oool0oooo0?noM0030000000307Boo`3oool0oooo02P0oooo00<0okmd0000
000000000`0000000`00M;l0oooo0?ooo`020?ooo`030;md0000000007Bo00D0oooo00D0_g@00000
00000000000007Boo`030?ooo`030;mdB02Lgol0oooo0080oooo00<0okmG0000000000000`000000
1@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3oool0Q03oool006D0oooo00L0_g@0
001d_`3oool0oooo0?oOW0180000M;oo0080oooo00X0oooO09a8B02Lgol0oooo0?oo_`1d07@0_ooo
0?ooo`2LB4P0W=oo1@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oooc@0oooo00<0W4Q809cOo`3o
ool00`3oool02P3ooml0W4Q809cOo`3oool0oono07@0M02oool0oooo09a8B02Lgol50?ooo`0609a8
M02oool0oooo0?oo_`1d07@0_ooo;03oool00`2LB4P0W=oo0?ooo`050?ooo`030;md0000000007Bo
00@0oooo00L0_g@0001d_`3oool0oooo0?oOW0180000M;oo0080oooo00X0oooO09a8B02Lgol0oooo
0?oo_`1d07@0_ooo0?ooo`2LB4P0W=oo1@3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooohD0oooo
001Z0?ooo`030?noM000M;l0oooo0080oooo00D0oooO09a8M02ooml0W4Qd0;ooo`020?ooo`0309a8
B02Lgol0oooo00<0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0c0?ooo`0309a8
B02Lgol0oooo00@0oooo00D0oooO09a8M02ooml0W4Qd0;ooo`020?ooo`0309a8B02Lgol0oooo00<0
oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0[0?ooo`0309a8B02Lgol0oooo0140
oooo00<0okmd001d_`3oool00P3oool01@3ooml0W4Qd0;oog`2LB7@0_ooo0080oooo00<0W4Q809cO
o`3oool00`3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo08@0oooo001Z0?ooo`03
0?noM000M;l0oooo00<0oooo00<0oono07@0B02Lgol00`3oool00`2LB4P0W=oo0?ooo`030?ooo`03
0=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool0<`3oool00`2LB4P0W=oo0?ooo`050?ooo`03
0?oo_`1d04P0W=oo00<0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?noM000M;l0oooo02/0oooo00<0W4Q809cOo`3oool04@3oool00`3o_g@007Bo0?ooo`030?ooo`03
0?oo_`1d04P0W=oo00<0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`03
0?noM000M;l0oooo08@0oooo001Z0?ooo`0309a8001d_ol0oooo0080oooo00D0oono07@0M02ooml0
W4Q809cOo`020?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@0
07Bo0?ooo`0c0?ooo`0309a8B02Lgol0oooo00@0oooo00D0oono07@0M02ooml0W4Q809cOo`020?oo
o`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0[0?oo
o`0309a8B02Lgol0oooo0140oooo00<0W4P007Boo`3oool00P3oool01@3ookl0M01d0;oog`2LB4P0
W=oo0080oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0
oooo08@0oooo001U0?ooo`030?oo_`1d000000000080000000h0B9cO0?ooo`3oool0oooo0?oo_`1d
07@0_ooo0?ooo`3ooml0W4Q809cOo`3oool0W4Q809cOo`@0oooo00<0gia804RLg`3oool00P3oool0
0`3o_g@007Bo0?ooo`0c0?ooo`0309a8B02Lgol0oooo00<0oooo00X0oono07@0M02oool0oooo0?oo
g`2LB4P0W=oo0?ooo`2LB4P0W=oo103oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo
02/0oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M000000000020000000>04RLg`3oool0oooo
0?ooo`3ookl0M01d0;ooo`3oool0oooO09a8B02Lgol0oooo09a8B02Lgol40?ooo`030=nLB018W=l0
oooo0080oooo00<0okmd001d_`3oool0Q03oool006D0oooo00<0oono07@0M02oool01P3oool00`2o
M7@0_ooo0?ooo`020?ooo`050?oog`2LM9`0gooo09a8B02Lgol0103oool00`3o_g@0B9cO0?ooo`02
0?ooo`030=nLB018W=l0oooo03<0oooo00<0W4Q809cOo`3oool00`3oool00`2oM7@0_ooo0?ooo`02
0?ooo`050?oog`2LM9`0gooo09a8B02Lgol0103oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018
W=l0oooo02/0oooo00<0W4Q809cOo`3oool0303oool00`3ookl0M01d0;ooo`060?ooo`030;mdM02o
ool0oooo0080oooo00D0oooO09adW03Oool0W4Q809cOo`040?ooo`030?noM018W=l0oooo0080oooo
00<0gia804RLg`3oool0Q03oool006D0oooo00<0oono07@0M02oool02`3oool01@3OW4P000000018
W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL04P0M02ooola0?ooo`050=nLB000000004RL
09a8B02Lgol02@3oool01@3OW4P000000018W02LB4P0W=oo00D0oooo00H0W4P007Boo`3oool0omnL
04P0M02ooolY0?ooo`050=nLB000000004RL09a8B02Lgol03@3oool00`3ookl0M01d0;ooo`0;0?oo
o`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooohD0oooo
001U0?ooo`030?oo_`1d000000000080000000<0001d0;ooo`3oool0203oool00`3OW4P0001809cO
o`050?ooo`050?oo_`1d000000000000B02Lgol0103oool0103OW4P0000000000000B9`/0?ooo`03
0=nLB00004P0W=oo00/0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0W=oo
00@0oooo00<0oono07A8W03oool09@3oool00`3OW4P0001809cOo`0=0?ooo`030?oo_`1d00000000
0080000000<0001d0;ooo`3oool0203oool00`3OW4P0001809cOo`050?ooo`050?oo_`1d00000000
0000B02Lgol0103oool00`3ookl0M4RL0?ooo`1o0?ooo`00Q@3oool01P3ogi`0B4RL0?ooo`3oool0
giad09cOod/0oooo00<0_gA809cOo`3oool0EP3oool00`2oM4P0W=oo0?ooo`1n0?ooo`00Q@3oool0
1P2oM00004RL0?ooo`3oool0W4Q809cOod/0oooo00<0okmd04RLg`3oool0EP3oool00`3o_g@0B9cO
0?ooo`1n0?ooo`00Q@3oool01@3OW7@0M7A8000000000000B9cO04`0oooo00<0oono07A8W03oool0
EP3oool00`3ookl0M4RL0?ooo`1n0?ooo`00Q@3oool00`3OW4P0M;oo0?ooo`1?0?ooo`030=nLB01d
_ol0oooo05H0oooo00<0gia807Boo`3oool0O@3oool008D0oooo00<0oono07@00018W=l0B`3oool0
1P3ookl0M4RL0?ooo`3oool0omnL04Qd_e<0oooo00H0oono07A8W03oool0oooo0?oOW018M;mR0?oo
o`040?oog`2LB0000000001d_`d0oooo00@0_g@000000000B9`0gooo1`3oool002X0oooo00<00000
0?ooo`3oool0FP3oool0102LB00000000000001d_om80?ooo`030?oo_`1d000000000080000000<0
07Bo0?ooo`3oool0D@3oool00`3ookl0M0000000000200000003001d_`3oool0oooo0600oooo00<0
oooO09adW03Oool03`3oool00`3ooml0W7BL0=ooo`070?ooo`00:P3oool00`000000oooo0?ooo`3o
0?ooofP0oooo00<0oooO09adW03Oool03`3oool00`3ooml0W7BL0=ooo`070?ooo`00:P3oool00`00
0000oooo0?ooo`3o0?oood40oooo00<0oono07@0000000000`0000000`0004P0W=oo0?ooo`0N0?oo
o`030?oog`2LM9`0gooo0080oooo00/0omnL04P000000000001d0;oo_`1d0000001809cOo`2LB000
001809cOo`020?ooo`030?oog`2LM9`0gooo00L0oooo000Z0?ooo`030000003oool0oooo0?l0oooo
@`3oool00`3ookl0M01d0;ooo`0R0?ooo`030?oog`2LM9`0gooo00<0oooo00T0omnL04Q8W03oool0
oono07@0M02oool0oooo09a8B02Lgol00`3oool00`3ooml0W7BL0=ooo`070?ooo`00:P3oool00`00
0000oooo0?ooo`3o0?oood<0oooo00<0oono07@0M02oool08P3oool00`3ooml0W7BL0=ooo`030?oo
o`090?oOW018B9`0oooo0?oo_`1d07@0_ooo0?ooo`2LB4P0W=oo00<0oooo00<0oooO09adW03Oool0
1`3oool00280ooooo`000012000000`0oooo00<0oono07@0M02oool08P3oool00`3ooml0W7BL0=oo
o`030?ooo`090?oOW018B9`0oooo0?oo_`1d07@0_ooo0?ooo`2LB4P0W=oo00<0oooo00<0oooO09ad
W03Oool01`3oool002X0oooo0P00000>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01@0oooo00@0oono07@00000
0000M;oo8@3oool00`3ooml0W7BL0=ooo`030?ooo`090?oOW0180000M;oo0?oOW0180000B9cO0?oo
_`1d04P0W=oo00<0oooo00<0oooO09adW03Oool01`3oool002X0oooo0P00001=0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1C0?ooo`050=nLB000
0000001d0;oo_`1d00000P0000000`1d_ol0oooo0?ooo`0L0?ooo`030?oog`2LM9`0gooo0080oooo
00T0omnL04P00000B4P0M0000000001d_ol0W4P000000000M;l0103oool00`3ooml0W7BL0=ooo`07
0?ooo`00:P3oool00`000000oooo0000003o0?ooofP0oooo00<0oooO09adW03Oool03`3oool00`3o
oml0W7BL0=ooo`070?ooo`00:P3oool00`000000oooo0000003o0?ooofP0oooo00<0oooO09adW03O
ool03`3oool00`3ooml0W7BL0=ooo`070?ooo`00:P3oool010000000oooo0?ooo`00003o0?ooofL0
oooo00@0oooO09a80000000007Bo3@3oool0102oM00000000018W03Oool70?ooo`00:P3oool01000
0000oooo0?ooo`00003o0?oooh<0oooo000Z0?ooo`050000003oool0oooo0?ooo`000000o`3ooon2
0?ooo`00:P3oool01@000000oooo0?ooo`3oool000000?l0ooooPP3oool002X0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`3o0?ooogl0oooo000Z0?ooo`8000000`3oool00`000000
oooo0?ooo`3o0?ooogl0oooo000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
o`3ooomn0?ooo`00:P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0ooooOP3o
ool002X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooogd0oooo000Z0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooomm0?ooo`00:P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooO03oool002X0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`3o0?ooog`0oooo000Z0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0o`3ooomk0?ooo`00:P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0?l0ooooN`3oool002X0oooo0P0000080?ooo`030000003oool0oooo0?l0ooooNP3oool002X0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooogX0oooo000Z0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`<00000E@3oool002X0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooa/0oooo1P00001H0?ooo`00:P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0?l0oooo4`3oool7000005h0oooo000Z0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3oool<0?ooo`H00000I@3oool002X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooo`H0oooo1P00001[0?ooo`00
:P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?h0oooo1P00001a0?ooo`00:P3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?P0oooo1P00001g0?ooo`00:P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0?<0oooo1000001m0?ooo`00:P3oool20000
00d0oooo00<000000?ooo`3oool0k`3oool400000840oooo000Z0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0j@3oool5000008D0oooo000Z0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0i@3oool4000008X0oooo000Z0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0h03oool4000008h0oooo000Z0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0f`3oool400000980oooo000Z0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0f03oool3000009H0oooo000M0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3o
ool00`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0=@0oooo0`00002I0?ooo`00
7P3oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo00@0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`3A0?ooo`<00000W03oool001l0oooo00<0okmd0000B02Lgol0203o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0<d0oooo0`00002O0?ooo`00803oool0
0`3ogi`0B00004RLg`070?ooo`<000004@3oool00`000000oooo0?ooo`3:0?ooo`<00000XP3oool0
0280oooo00<0W4P004RLg`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0<D0oooo1000002U0?ooo`008`3oool00`2LB7@0_ooo0?ooo`040?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0`@3oool300000:T0oooo000N0?ooo`030=nLB01d_ol0oooo0080oooo
00<0_g@007Boo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0;l0oooo
0P00002/0?ooo`007P3oool01`3o_g@0001d0;ooo`3oool0okmd0000B02Lgol01@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0;`0oooo0P00002^0?ooo`007`3oool01@3o_g@00000
0000000004P0W=oo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`2j0?ooo`80
0000/03oool002X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2g0?ooo`800000
/P3oool002X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`2e0?ooo`800000]03o
ool002X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2b0?ooo`800000]P3oool0
02X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`2_0?ooo`<00000^03oool002X0
oooo0P00000H0?ooo`030000003oool0oooo0:`0oooo0P00002k0?ooo`00:P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo0:T0oooo0P00002m0?ooo`00:P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0:L0oooo0P00002o0?ooo`00:P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo0:@0oooo0P0000310?ooo`00:P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0:80oooo0P0000330?ooo`00:P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo09l0oooo0P0000350?ooo`00:P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo09d0oooo0P0000370?ooo`00:P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo09X0oooo0P0000390?ooo`00:P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo09T0oooo00<000000?ooo`3oool0b@3oool002X0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`2F0?ooo`800000c03oool002X0oooo0P00000M0?ooo`030000003oool0oooo09D0
oooo00<000000?ooo`3oool0c03oool002X0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`2B0?ooo`800000c`3oool002X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`2@0?ooo`800000d@3oool002X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo0=40oooo000Z0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`3B0?ooo`00:P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo08X0oooo0P00003E0?ooo`00:P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo08T0oooo00<000000?ooo`3oool0e@3oool002X0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0=H0oooo000Z0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0Q@3oool200000=T0oooo000Z0?ooo`8000008P3oool00`00
0000oooo0?ooo`230?ooo`030000003oool0oooo0=T0oooo000Z0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`3J0?ooo`00:P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo07l0oooo0P00003M0?ooo`00:P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0g@3oool002X0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0=h0oooo000Z0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`3O0?oo
o`00803oool01@3ogi`0B000000000000000M;oo00D0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo0>00oooo000R0?ooo`030;md001d_ol0oooo00D0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0>40
oooo000R0?ooo`030;md001d_ol0oooo00D0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0>80oooo000N0?ooo`030=nLB0000000000000<0000000<0
M;oo0?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo07@0oooo00<0
00000?ooo`3oool0h`3oool001h0oooo00H0okmd0000M02oool0oooo0;md001d_ol60?ooo`<00000
9P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0>@0oooo000O0?ooo`050=nLB000
M;l0oooo0;md001d_ol01P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool0i@3oool00200oooo00@0W4P004RLg`2oM000M;oo1P3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0iP3oool00200oooo00@0
omnL04P0B018B000M;oo1P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool0i`3oool00240oooo00<0okmd0000001d_ol01P3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool0j03oool002X0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0>T0oooo000Z0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`3Z0?oo
o`00:P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool0j`3oool002X0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1V0?ooo`030000
003oool0oooo0>`0oooo000Z0?ooo`800000;03oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0>`0oooo000Z0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`3]0?ooo`00:P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool0kP3oool002X0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo0>l0oooo000Z0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`3`0?ooo`00:P3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0l@3oool002X0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo0?40oooo000Z0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`3b0?oo
o`00:P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0l`3oool002X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo0?@0oooo000Z0?ooo`800000<P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0?D0oooo000Z0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`3e0?ooo`00:P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool0mP3oool002X0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0?L0oooo000Z0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`3h0?ooo`00:P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0n03oool002X0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0?T0oooo000Z0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`3j0?oo
o`00:P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0nP3oool002X0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0?/0oooo000Z0?ooo`800000=`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0?`0oooo000Z0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`3l0?ooo`00:P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0o@3oool002X0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo0?h0oooo000Z0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`3n0?ooo`00:P3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0o`3oool00200oooo00D0_g@0
000000000000001d0;ooo`050?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`3o0?ooo`007`3oool01P3OW4P007Bo0?ooo`3oool0okmd001d_`D0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0?l0oooo
0@3oool001h0oooo00<0oono07@0001d_ol00P3oool00`3ookl0M4RL0?ooo`040?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`3o0?ooo`80oooo000N
0?ooo`070?noM000B4P0M01d0;ooo`3oool0gia8001d_`050?ooo`<00000>P3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo0?l0oooo0P3oool001h0oooo00<0omnL04Q8W03o_g@00P00
00000`00B9`0oooo0?ooo`040?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`3o0?ooo`<0oooo000N0?ooo`030?oo_`1d07@0_ooo00T0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0oooo103oool0
01l0oooo00<0_g@004RLg`3oool0203oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0o`3oool40?ooo`007`3oool00`3ookl0M000001d_`080?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`3o0?ooo`D0
oooo000Q0?ooo`040;md0000000000000018W0D0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo0?l0oooo1@3oool002X0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo1P3oool002X0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo1P3o
ool002X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo0?l0oooo1`3oool002X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo0?l0oooo1`3oool002X0oooo0P0000110?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0o`3oool80?ooo`00:P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool0o`3oool80?ooo`00:P3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3oool90?ooo`00:P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0o`3oool9
0?ooo`00:P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0o`3oool90?ooo`00:P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0o`3oool:0?ooo`00:P3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0o`3oool:0?ooo`00:P3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0o`3oool;0?ooo`00:P3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0o`3oool;
0?ooo`00:P3oool2000004H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?oo
o``0oooo000Z0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`3o0?ooo``0oooo000Z0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000Z0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`3o0?ooo`d0oooo000Z0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`3o0?ooo`h0oooo000Z0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`3o0?oo
o`h0oooo000Z0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`3o0?ooo`h0oooo000Z0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000Z0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`3o0?ooo`l0oooo000Z0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`3o0?oooa00oooo000Z0?oo
o`800000C03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0?l0oooo403oool002X0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0?l0
oooo4@3oool002X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0?l0oooo4@3oool002X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo0?l0oooo4P3oool002X0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo4P3oool002X0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0?l0oooo4P3oool001l0
oooo00D0_g@00000000000000000001d_`060?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`3o0?oooa<0oooo000N0?ooo`030?noM000M;l0oooo0080
oooo00<0_gA809cOo`3oool0103oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0o`3ooolC0?ooo`007P3oool00`3OW4P0B9cO0?ooo`020?ooo`030;md
001d_ol0oooo00@0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0?l0oooo4`3oool001h0oooo00<0okmd0018W03oool00P3oool00`2LB4P0W=oo0?oo
o`040?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`3o0?oooa@0oooo000O0?ooo`050=nLB0000000000000000018W=l01P3oool300000500oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`3o0?oooa@0oooo000N0?ooo`030?oo_`1dB9`0
oooo0080oooo00<0W4Qd0;ooo`3oool0103oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`007P3oool00`3o_g@0B9cO0?ooo`020?oo
o`030;md001d_ol0oooo00@0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0?l0oooo5@3oool001h0oooo00L0omnL04P0M02oool0oooo0?oOW01807@0
_ooo00D0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo0?l0oooo5@3oool001l0oooo00D0okmd000000000000001809cOo`060?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`3o0?oooaD0oooo000Z0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?oo
oaH0oooo000Z0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`3o0?oooaH0oooo000Z0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`3o0?oooaH0oooo000Z0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?oooaL0oooo000Z0?ooo`800000E@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0oooo5`3oool002X0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0oooo5`3oool002X0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0
oooo603oool002X0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0?l0oooo603oool002X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0?l0oooo603oool002X0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo6@3oool002X0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo6@3oool002X0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0
oooo6@3oool002X0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0?l0oooo6P3oool002X0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0?l0oooo6P3oool002X0oooo0P00001K0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`00:P3oool00`000000oooo0?ooo`1K0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`00:P3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`00
:P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
o`3ooolK0?ooo`00:P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0o`3ooolK0?ooo`00:P3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`00:P3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`00:P3oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolL0?ooo`00
:P3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
o`3ooolM0?ooo`00:P3oool200000600oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?oooad0oooo000Z0?ooo`030000003oool0oooo0600oooo00D000000?ooo`3oool0oooo0000
003o0?oooal0oooo000Z0?ooo`030000003oool0oooo0600oooo00D000000?ooo`3oool0oooo0000
003o0?oooal0oooo000Z0?ooo`030000003oool0oooo0600oooo00@000000?ooo`3oool00000o`3o
oolP0?ooo`00:P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool000000?l0oooo803oool0
02X0oooo00<000000?ooo`3oool0HP3oool200000?l0oooo803oool001D0oooo00<0okmd00000000
00000`0000001@00M;l0oooo0?ooo`3oool0okmd00<0000000<0M;oo0?ooo`3oool0103oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo0?l0oooo7`3oool001P0oooo00<0W4Q809cOo`3o
ool0103oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`D0oooo00<000000?ooo`3oool0o`3ooon4
0?ooo`00603oool00`2LB4P0W=oo0?ooo`030?ooo`030?noM000M;l0oooo0080oooo00<0gia804RL
g`3oool0103oool00`000000oooo0?ooo`3o0?oooh@0oooo000H0?ooo`0309a8B02Lgol0oooo00<0
oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`040?ooo`030000003oool0oooo0?l0
ooooQ03oool001P0oooo00<0W4Q809cOo`3oool00`3oool00`3OW4P0B9cO0?ooo`020?ooo`030?no
M000M;l0oooo00@0oooo0`00003o0?oooh@0oooo000H0?ooo`0309a8B02Lgol0oooo00<0oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`3o0?oooh/0oooo000H0?ooo`0309a8B02Lgol0
oooo00<0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`3o0?oooh/0oooo000E0?oo
o`050=nLB000000004RL09a8B02Lgol01@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooool0oooo
S03oool001L0oooo00<0gia80000B02Lgol01@3oool01@3ookl0M0000000000004P0W=oo0?l0oooo
S@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo
/@3oool00?l0oooo/@3oool00?l0oooo/@3oool000D0oooo00D0W4P0000000000000001809cOo`0G
0?ooo`040?oog`2LB0000000001d_bH0oooo00@0_g@000000000B9`0goooo`3ooomR0?ooo`00203o
ool00`3ogi`0B01809cOo`0F0?ooo`030?oog`2LM9`0gooo02P0oooo00<0oooO09adW03Oool0o`3o
oomR0?ooo`002@3oool00`2oM4P0W=oo0?ooo`0E0?ooo`030?oog`2LM9`0gooo00d0oooo00<0oono
07Ad_`3oool0603oool00`3ooml0W7BL0=ooo`3o0?ooof80oooo00040?ooo`070?oo_`1d00000000
0000000007@0M7A809cOo`0F0?ooo`030?oog`2LM9`0gooo0080oooo00h0omnL04P000000000001d
0;oo_`1d0000001809cOo`2LB000001809cOo`3oool0giad09cOo`H0oooo00<0_g@0000000000000
0P0000000`00B9`0oooo0?ooo`0:0?ooo`030?oog`2LM9`0gooo0?l0ooooHP3oool000@0oooo00L0
_g@007Boo`3oool0oooo0?noM00004P0W=oo01H0oooo00<0oooO09adW03Oool00`3oool02@3ogi`0
B4RL0?ooo`3ookl0M01d0;ooo`3oool0W4Q809cOo`020?ooo`030?oo_`1dM;l0oooo00D0oooo00<0
_g@004RLg`3oool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030?oog`2LM9`0gooo0?l0ooooHP3o
ool000<0oooo00<0oono07A8W03oool00`3oool00`2LB4P0W=oo0?ooo`0E0?ooo`030?oog`2LM9`0
gooo00<0oooo00T0omnL04Q8W03oool0oono07@0M02oool0oooo09a8B02Lgol00`3oool00`3OW7@0
W=oo0?ooo`090?ooo`030;md0000M;l0oooo00X0oooo00<0oooO09adW03Oool0o`3ooomR0?ooo`00
0`3oool00`3ookl0M4RL0?ooo`030?ooo`0309a8B02Lgol0oooo01D0oooo00<0oooO09adW03Oool0
0`3oool02@3ogi`0B4RL0?ooo`3ookl0M01d0;ooo`3oool0W4Q809cOo`030?ooo`030?oOW01dW=l0
oooo00D0oooo00D0W4P000000000000000000018W00<0?ooo`030?oog`2LM9`0gooo0?l0ooooHP3o
ool000@0oooo00L0_g@004RLg`3oool0oooo0;md000004P0W=oo01H0oooo00<0oooO09adW03Oool0
0`3oool02@3ogi`0B00007Boo`3ogi`0B00004RLg`3ookl0M01809cOo`040?ooo`030;mdM02oool0
oooo00<0oooo00L0okmd001d_`3oool0oooo0?oo_`1d0000B9cO00/0oooo00<0oooO09adW03Oool0
o`3ooomR0?ooo`001@3oool01`2LB000000000000000M;l0_g@00000001d_ol05@3oool00`3ooml0
W7BL0=ooo`020?ooo`090?oOW018000004Q807@000000000M;oo09a80000000007Bo00D0oooo00<0
omnL07BLg`3oool0103oool01P2oM0000000000000000000M7Ad04RLg`/0oooo00<0oooO09adW03O
ool0o`3ooomR0?ooo`008@3oool00`3ooml0W7BL0=ooo`0A0?ooo`030;mdM02oool0oooo00X0oooo
00<0omnL04P0000000000P0000000`18W=l0oooo0?ooo`020?ooo`030?oog`2LM9`0gooo0?l0oooo
HP3oool00240oooo00<0oooO09adW03Oool04@3oool00`3ogi`0M9cO0?ooo`0;0?ooo`0309a80000
B9`0oooo00H0oooo00<0oooO09adW03Oool0o`3ooomR0?ooo`008@3oool0103ooml0W4P000000000
M;lA0?ooo`030;nLW03Oool0oooo00/0oooo00<0gia80000M02oool0103oool0102oM00000000018
W03Ooooo0?ooof80oooo00150?ooo`030?noM00007@0_ooo0?l0ooooJ@3oool004H0oooo00<0okno
0;ooo`3oool0o`3ooomX0?ooo`00@P3oool01P3ookl0M01d0;ooo`3oool0_g@004RLgol0ooooJ@3o
ool004<0oooo00@0okmd00000000000004RLo`3ooomZ0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.67695*^06, -1.7896, \
94442.4, 0.0781374}}]
}, Closed]],

Cell[TextData[{
  "In general, it is good practice to identify the scales relevant to any \
dimensioned quantity and to express related quantities relative to the \
appropriate scale parameters so that functions can be expressed in numerical \
form without symbolic units or scales.  Many ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions, or mathematical functions, require numerical input.  For \
example, ",
  StyleBox["Plot", "InlineInput",
    FontWeight->"Bold"],
  " requires its functions to evaluate to pure numbers.  Thus, to plot ",
  Cell[BoxData[
      \(TraditionalForm\`g(r)\)]],
  " we have to extract the dimensions and scales anyway, whether or not those \
dimensions would pose problems for the formulation of conditions."
}], "Text"],

Cell["\<\
It is good practice to identify the scales relevant to dimensioned quantities \
and to employ dimensionless scaled functions whenever possible!\
\>", "Advice"]
}, Closed]],

Cell[CellGroupData[{

Cell["Nondimensionalization", "Section"],

Cell["\<\
Plotting commands deal with pure numbers, but the functions encountered as \
solutions to problems in science and engineering usually involve quantities \
with dimensions and units and often have several parameters describing the \
properties of some system.  Such functions must be nondimensionalized and \
must evaluate to pure numbers for plotting purposes.  Sometimes this can be \
done simply by replacing appropriate parameters by unity, effectively \
rescaling the variables in terms of appropriate dimensional parameters, or by \
giving explicit values in a consistent system of units.  The axis labels \
should then specify the units.  Other times we need to re-express the \
function in terms of appropriate dimensionless combinations of variables and \
parameters.  It is then appropriate to use axis labels to express the \
relevant combinations of variables.\
\>", "Text"],

Cell["For example, the Planck black-body formula ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(planck[\[Omega], 
        T]\  = \(k\_B\ T\ \[Omega]\^\(\(3\)\(\ \)\)\)\/\(\(\[Pi]\^2\) \
\(c\^2\)\(\ \)\((E\^\(\(\(\[HBar]\)\(\ \)\(\[Omega]\)\(\ \)\)\/\(\(k\_B\) T\)\
\) - 1)\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(\(T\ \[Omega]\^3\ k\_B\)\/\(c\^2\ \((\(-1\) + \[ExponentialE]\^\(\(\
\[Omega]\ \[HBar]\)\/\(T\ k\_B\)\))\)\ \[Pi]\^2\)\)], "Output"]
}, Closed]],

Cell["\<\
clearly exhibits a scaling relationship between its temperature and energy \
variables.  Hence, we can simplify the expression by making the replacement\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(planck[y]\  = \ 
      planck[\[Omega], T]\  /. \[Omega] \[Rule] k\_B\ T\ y/\[HBar]\  // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(\(T\^4\ y\^3\ k\_B\%4\)\/\(c\^2\ \((\(-1\) + \[ExponentialE]\^y)\)\ \
\[Pi]\^2\ \[HBar]\^3\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Now we find that the function can be described as a dimensionless function \
of ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " times a temperature-dependent normalization factor.  Therefore, to plot \
this function we need to divide out the normalization factor.  We then obtain \
a form suitable for plotting and use the labels to report the relevant \
dimensionless variables."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(norm = \((k\_B\ T)\)\^4\/\(\(\[Pi]\^2\) \(\[HBar]\^3\) c\^2\);\)\), "\
\[IndentingNewLine]", 
    \(\(Plot[Evaluate[planck[y]/norm], {y, 0, 10}, 
        GridLines \[Rule] Automatic, Frame \[Rule] True, 
        FrameLabel \[Rule] {\*"\"\<\[HBar]\[VeryThinSpace]\[Omega] / \!\(k\_B\
\)T\>\"", \ \*"\"\<I / \
((\!\(k\_B\)T\!\(\()\^4\)\)/\!\(\[Pi]\^2\)\!\(\[HBar]\^3\)\!\(c\^2\))\>\""}, 
        PlotLabel \[Rule] "\<Planck Distribution\>"];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.414093 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -25.625 -21.5625 ]
[.5 -0.0125 25.625 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .09753 -18 -4.5 ]
[-0.0125 .09753 0 4.5 ]
[-0.0125 .18035 -18 -4.5 ]
[-0.0125 .18035 0 4.5 ]
[-0.0125 .26317 -18 -4.5 ]
[-0.0125 .26317 0 4.5 ]
[-0.0125 .34599 -18 -4.5 ]
[-0.0125 .34599 0 4.5 ]
[-0.0125 .42881 -6 -4.5 ]
[-0.0125 .42881 0 4.5 ]
[-0.0125 .51163 -18 -4.5 ]
[-0.0125 .51163 0 4.5 ]
[-0.0125 .59445 -18 -4.5 ]
[-0.0125 .59445 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.9375 -55.7188 ]
[-0.01875 .30902 -18 55.7188 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -59 0 ]
[.5 .63053 59 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.21429 0 m
.21429 .61803 L
s
.40476 0 m
.40476 .61803 L
s
.59524 0 m
.59524 .61803 L
s
.78571 0 m
.78571 .61803 L
s
0 .09753 m
1 .09753 L
s
0 .18035 m
1 .18035 L
s
0 .26317 m
1 .26317 L
s
0 .34599 m
1 .34599 L
s
0 .42881 m
1 .42881 L
s
0 .51163 m
1 .51163 L
s
0 .59445 m
1 .59445 L
s
0 g
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -86.625 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Mathematica3Mono
%%IncludeFont: Mathematica3Mono
/Mathematica3Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\321) show
69.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.563 0.000 rmoveto
69.563 12.813 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.563 12.813 moveto
(\\220) show
93.563 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
99.563 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
104.250 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
110.250 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .09753 m
.00625 .09753 L
s
[(0.2)] -0.0125 .09753 1 0 Mshowa
0 .18035 m
.00625 .18035 L
s
[(0.4)] -0.0125 .18035 1 0 Mshowa
0 .26317 m
.00625 .26317 L
s
[(0.6)] -0.0125 .26317 1 0 Mshowa
0 .34599 m
.00625 .34599 L
s
[(0.8)] -0.0125 .34599 1 0 Mshowa
0 .42881 m
.00625 .42881 L
s
[(1)] -0.0125 .42881 1 0 Mshowa
0 .51163 m
.00625 .51163 L
s
[(1.2)] -0.0125 .51163 1 0 Mshowa
0 .59445 m
.00625 .59445 L
s
[(1.4)] -0.0125 .59445 1 0 Mshowa
.125 Mabswid
0 .03542 m
.00375 .03542 L
s
0 .05612 m
.00375 .05612 L
s
0 .07683 m
.00375 .07683 L
s
0 .11824 m
.00375 .11824 L
s
0 .13894 m
.00375 .13894 L
s
0 .15965 m
.00375 .15965 L
s
0 .20106 m
.00375 .20106 L
s
0 .22176 m
.00375 .22176 L
s
0 .24247 m
.00375 .24247 L
s
0 .28388 m
.00375 .28388 L
s
0 .30458 m
.00375 .30458 L
s
0 .32528 m
.00375 .32528 L
s
0 .36669 m
.00375 .36669 L
s
0 .3874 m
.00375 .3874 L
s
0 .4081 m
.00375 .4081 L
s
0 .44951 m
.00375 .44951 L
s
0 .47022 m
.00375 .47022 L
s
0 .49092 m
.00375 .49092 L
s
0 .53233 m
.00375 .53233 L
s
0 .55304 m
.00375 .55304 L
s
0 .57374 m
.00375 .57374 L
s
0 .61515 m
.00375 .61515 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -141.188 -10.4688 Mabsadd m
1 1 Mabs scale
currentpoint translate
116.719 10.4688 translate
90 rotate
-116.719 -10.4688 translate
0 20.9375 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 13.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(I) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.188 moveto
(\\220) show
87.000 13.188 moveto
(H) show
93.000 13.188 moveto
(H) show
99.000 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
105.000 14.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
109.688 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
115.688 13.188 moveto
(L) show
121.688 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
126.375 13.188 moveto
(\\220) show
132.375 13.188 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
138.375 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
143.063 13.188 moveto
%%IncludeResource: font Mathematica3Mono
%%IncludeFont: Mathematica3Mono
/Mathematica3Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\321) show
149.063 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
153.750 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
159.750 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
164.438 13.188 moveto
(L) show
170.438 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09753 m
1 .09753 L
s
.99375 .18035 m
1 .18035 L
s
.99375 .26317 m
1 .26317 L
s
.99375 .34599 m
1 .34599 L
s
.99375 .42881 m
1 .42881 L
s
.99375 .51163 m
1 .51163 L
s
.99375 .59445 m
1 .59445 L
s
.125 Mabswid
.99625 .03542 m
1 .03542 L
s
.99625 .05612 m
1 .05612 L
s
.99625 .07683 m
1 .07683 L
s
.99625 .11824 m
1 .11824 L
s
.99625 .13894 m
1 .13894 L
s
.99625 .15965 m
1 .15965 L
s
.99625 .20106 m
1 .20106 L
s
.99625 .22176 m
1 .22176 L
s
.99625 .24247 m
1 .24247 L
s
.99625 .28388 m
1 .28388 L
s
.99625 .30458 m
1 .30458 L
s
.99625 .32528 m
1 .32528 L
s
.99625 .36669 m
1 .36669 L
s
.99625 .3874 m
1 .3874 L
s
.99625 .4081 m
1 .4081 L
s
.99625 .44951 m
1 .44951 L
s
.99625 .47022 m
1 .47022 L
s
.99625 .49092 m
1 .49092 L
s
.99625 .53233 m
1 .53233 L
s
.99625 .55304 m
1 .55304 L
s
.99625 .57374 m
1 .57374 L
s
.99625 .61515 m
1 .61515 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -120 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Planck) show
105.000 12.813 moveto
(Distribution) show
177.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01478 L
.02605 .01494 L
.02729 .01526 L
.02846 .01568 L
.03053 .01671 L
.03279 .01822 L
.03527 .02036 L
.0379 .02312 L
.04262 .02932 L
.05205 .046 L
.06244 .06997 L
.10458 .2039 L
.14487 .3463 L
.18364 .46403 L
.20477 .51427 L
.22486 .55155 L
.23445 .56568 L
.24467 .57815 L
.25425 .58747 L
.26306 .59407 L
.26806 .59701 L
.27334 .59948 L
.27865 .60133 L
.28166 .60211 L
.28447 .60266 L
.28572 .60285 L
.28708 .60302 L
.28837 .60315 L
.28956 .60323 L
.29063 .60329 L
.29181 .60332 L
.29304 .60332 L
.2942 .60329 L
.29548 .60323 L
.29612 .60319 L
.29682 .60314 L
.29922 .60288 L
.30058 .60268 L
.30203 .60243 L
.30464 .60189 L
.30997 .60038 L
.31488 .59855 L
.32598 .59291 L
.33577 .58636 L
.34614 .57795 L
.38402 .5368 L
.42436 .48095 L
.46319 .42201 L
.50446 .35917 L
Mistroke
.54423 .30207 L
.58247 .25229 L
.62317 .20588 L
.66235 .16781 L
.70398 .13417 L
.7441 .10779 L
.78271 .08728 L
.82376 .06994 L
.8633 .05685 L
.90132 .04699 L
.9418 .03887 L
.97619 .03352 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012R000`400?l00000o`00003oo`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3oool50?ooo`030=nLB000
000000000080000000<004RL0?ooo`3oool0Y03oool00>X0oooo00<0oono07Ad_`3oool0603oool0
1P2oM4P0W=oo0?ooo`3oool0gia804RLgjD0oooo003<0?ooo`0C0?oo_`1d000000000000B02Lgol0
oono07@000000000001d0;ooo`3oool0oono07@00000000007Bo0;md00000000001d0;ooo`0<0?oo
o`030=nLM02Lgol0oooo00h0oooo00D0_g@000000018W=l0oooo09a800020000000;04RLg`3oool0
_gA809cOo`3oool0oono07@0001d_ol0oooo0?oOW01800000`0000000`0007@0_ooo0?ooo`2L0?oo
o`00cP3oool00`3OW7@0W=oo0?ooo`020?ooo`0=0;mdM02oool0oooo0?ooo`3OW4P0M;oo0?ooo`3o
_g@007Bo0?ooo`3ogi`0B4RL0=ooo`0;0?ooo`030?oo_`1dM;l0oooo00l0oooo00D0gia804RLg`3o
ool0gia8001d_`030?ooo`050;md0000000000000000001d_ol0103oool00`3ogi`0B4RL0?ooo`2O
0?ooo`00cP3oool00`3ogi`0M9cO0?ooo`020?ooo`090?noW02Lgol0oooo0?ooo`3o_i`0W=oo0?oo
o`3ooml0W9bo0080oooo00<0giad09cOo`3oool02`3oool00`3OW7@0W=oo0?ooo`0>0?ooo`040=nL
B000B9`0gia80018W0@0oooo00D0_gA809cOo`3oool0oono07A8W0040?ooo`030?oOW018B9`0oooo
09l0oooo003>0?ooo`030?oo_`1dB9`0gooo0080oooo00H0oono09bLg`3oool0oooo0?oOW02L_ol2
0?ooo`050;mdM02oool0oooo0?noW02Lgol0303oool00`3ogi`0M9cO0?ooo`0>0?ooo`040=nLB018
B4P0001809cOo`@0oooo00H0_gA809cOo`3oool0oono07@0M02oool30?ooo`030?oOW018B9`0oooo
09l0oooo003?0?ooo`070;md00000000M;oo0?ooo`3ooml0W7BL0=ooo`020?ooo`030;mdB02Lgol0
oooo00<0oooo00<0oknL09cOo`3oool0303oool00`2oM7@0_ooo0?ooo`0=0?ooo`040=nLB018W=l0
omnL07BLg`<0oooo00<0gia80000000000000P0000002`1d_ol0oooo0?oOW018M;l0oooo0?oOW018
B9`0oooo0?oo_`1d07@0_ooo09`0oooo003=0?ooo`050?oog`3Ogol0gia807Boo`2oM0000P000000
1`18W=l0oooo0?ooo`3oool0oooO09adW03Oool00`3oool00`2o_kl0oooo0?ooo`0<0?ooo`030?oO
W01dW=l0oooo00d0oooo00<0gia804RLW01d00000P0000000`18W=l0oooo0?ooo`060?ooo`090?oO
W018M;l0oooo0?oOW018B9`0oooo0?oo_`1d07@0_ooo09`0oooo003=0?ooo`040?oog`2LB0000000
04RLgad0oooo00<0_gAd0;ooo`3oool0303oool00`3OW4P0B9cO0?ooo`0;0?ooo`090?oOW018M;l0
oooo0?oOW018B9`0oooo0?oo_`1d07@0_ooo09`0oooo003?0?ooo`040?oo_`1d0000000007Booa/0
oooo00<0omnL07BLg`3oool0303oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?oOW0180000000000@0
000000<0001d0;ooo`3oool0V`3oool00<h0oooo00D0oono07@00000B9`0gooo0=oOg`0L0?ooo`03
0;nLW03Oool0oooo00X0oooo00<0_g@000000018W=l0/@3oool00?l0oooo/@3oool00?l0oooo/@3o
ool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool004l0oooo00D0okmd000000000000
000007Boo`0i0?ooo`030?oo_`1d0000000000@0000000<0M;oo0?ooo`3oool0>@3oool01@3ogi`0
B000000000000000M;oo03X0oooo00D0_g@0000000000000001d0;ooo`0j0?ooo`050;md00000000
000000000000M;l0=@3oool00`3o_g@000000000000300000005001d_`3oool0oooo0?ooo`3o_g@0
0`0000000`1d_ol0oooo0?ooo`0G0?ooo`00C`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooocT0
oooo00<0_g@00000M02oool00P3oool00`3OW7@0W=oo0?ooo`0l0?ooo`030;md001d_ol0oooo03T0
oooo00H0gia8001d_`3oool0oooo0?noM000M;li0?ooo`030?noM000M;l0oooo0080oooo00<0_gA8
09cOo`3oool0=P3oool00`2LB4P0W=oo0?ooo`040?ooo`0609a8M02oool0oooo0?oo_`1d07@0_ooo
603oool004h0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0i0?ooo`030?noM000
04P0W=oo0400oooo00<0_g@007Boo`3oool0>03oool00`3ookl0M00007Boo`020?ooo`030?oo_`1d
B9`0oooo03P0oooo00<0gia804RLg`3oool00P3oool00`2oM000M;oo0?ooo`0f0?ooo`0309a8B02L
gol0oooo00<0oooo00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0G0?ooo`00CP3oool0
0`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo03X0oooo00<0omnL04P00018W=l0>`3oool0
0`3OW4P00000000000030000000307Boo`3oool0oooo03H0oooo00L0okmd0018B01d07@0_ooo0?oo
o`3OW4P007Bo03T0oooo00<0okmd0018W03oool00P3oool00`2LB4P0W=oo0?ooo`0f0?ooo`0309a8
B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0G0?ooo`00CP3o
ool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo03`0oooo00<0W4P004RLg`3oool0>@3o
ool01P3o_g@0001d0;ooo`3oool0_g@007BoocT0oooo00<0omnL04Q8W03o_g@00P0000000`00B9`0
oooo0?ooo`0i0?ooo`050=nLB0000000000000000018W=l0>03oool00`2LB4P0W=oo0?ooo`030?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool05`3oool004h0oooo00<0gia804RLg`3o
ool00P3oool00`3o_g@007Bo0?ooo`0m0?ooo`0309a8M02oool0oooo03T0oooo00D0gia8001d_`3o
ool0_g@007Boo`0i0?ooo`030?oo_`1d07@0_ooo03d0oooo00<0oono07A8W03oool00P3oool00`2L
B7@0_ooo0?ooo`0f0?ooo`0309a8B02Lgol0oooo00<0oooo00<0gia804RLg`3oool00P3oool00`3o
_g@007Bo0?ooo`0G0?ooo`00CP3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo03P0
oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`0j0?ooo`0409a80018W=l0_g@007Bo
ocX0oooo00<0_g@004RLg`3oool0?03oool00`3o_g@0B9cO0?ooo`020?ooo`030;md001d_ol0oooo
03H0oooo00<0W4Q809cOo`3oool00`3oool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo
01L0oooo001?0?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo>@3oool01`3o_g@0001d0;ooo`3o
ool0okmd0000B02Lgol0>`3oool0103ogi`0B01804Q8001d_olj0?ooo`030?oo_`1d000007Bo03`0
oooo00L0omnL04P0M02oool0oooo0?oOW01807@0_ooo03@0oooo00D0gia800000000B9`0W4Q809cO
o`050?ooo`0609a8001d_ol0oooo0?oOW01807@0_ooo603oool004l0oooo00D0oono07@000000000
001809cOo`0k0?ooo`050?noM000000000000000B02Lgol0?@3oool00`3o_g@0000007Boo`0l0?oo
o`040;md0000000000000018W3X0oooo00D0okmd000000000000001809cOo`0g0?ooo`030=nLB000
04P0W=oo00D0oooo00D0oono07@000000000001809cOo`0I0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona0?ooo`00o`3ooona
0?ooo`00BP3ooooo0000050000005`3oool004X0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0E0?ooo`00?`3oool01@3o_g@00000000000000000M;oo00H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0E0?ooo`00?`3oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;oo
o`D0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
03d0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo
01D0oooo000n0?ooo`030?noM000M;l0oooo0080oooo00<0gia804RLg`3oool0103oool00`000000
oooo0?ooo`140?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0
oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool003h0oooo
00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`040?ooo`<000001@3oool2000003d0oooo
00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo
00<0001o0?ooo`3oool0@`3oool3000001L0oooo000n0?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool0103oool00`000000oooo0?ooo`070?ooo`800000>`3oool00`0007l0oooo0?oo
o`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`150?ooo`030000003oool0oooo01D0oooo000n0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd
001d_`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03P0oooo00<0001o
0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo00<0001o
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00?P3oool00`3o_g@0B9cO0?ooo`020?oo
o`030=nLB018W=l0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0g0?oo
o`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool003l0oooo00H0W4P007Boo`3o
ool0omnL04P0M02oool50?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0=`3oool0
0`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000o0?ooo`050?oo_`1d00000000
0000B02Lgol01P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03H0oooo00<0001o
0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo00<0001o
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo03D0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?oo
o`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0>`3oool3000000L0oooo00<000000?oo
o`3oool05@3oool004X0oooo0P00000=0?ooo`030000003oool0oooo03D0oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3o
ool0=@3oool6000000P0oooo0`00000G0?ooo`00BP3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo03@0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000
O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0;`3oool600000100oooo00<000000?ooo`3oool0
5@3oool004X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0d0?ooo`030000O`3o
ool0oooo03d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo02/0oooo1000000F0?ooo`030000003oool0oooo01D0oooo001:0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0<`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0
oooo03d0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0W0?ooo`@000006P3oool0
0`000000oooo0?ooo`0E0?ooo`00BP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
03<0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool08P3oool5000001h0oooo00<000000?ooo`3oool05@3oool004X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0b0?ooo`030000O`3oool0oooo03d0
oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo01h0
oooo1000000S0?ooo`030000003oool0oooo01D0oooo001:0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0<P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo
00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0J0?ooo`@000009`3oool00`000000oooo
0?ooo`0E0?ooo`00BP3oool200000140oooo00<000000?ooo`3oool0<@3oool00`0007l0oooo0?oo
o`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`0F0?ooo`@00000:@3oool3000001L0oooo001:0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0<@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`0C0?ooo`<00000;`3oool00`000000oooo0?ooo`0E
0?ooo`00BP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0300oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?oo
o`3oool03`3oool400000380oooo00<000000?ooo`3oool05@3oool004X0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0`0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo00`0oooo0`00000f0?ooo`03
0000003oool0oooo01D0oooo001:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
;`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0
?03oool00`0007l0oooo0?ooo`090?ooo`<00000>@3oool00`000000oooo0?ooo`0E0?ooo`00BP3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02l0oooo00<0001o0?ooo`3oool0?@3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool01`3o
ool2000003`0oooo00<000000?ooo`3oool05@3oool001X0oooo00<0okmd07Boo`3oool01@3oool0
0`2oM7@0_ooo0?ooo`0U0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;`3oool0
0`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`050?ooo`800000?P3oool00`000000oooo0?ooo`0E0?ooo`006P3oool00`3o
_g@0M;oo0?ooo`050?ooo`030;mdM02oool0oooo02D0oooo0P00000D0?ooo`030000003oool0oooo
02h0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool00P3oool3000003h0oooo0`00000G0?ooo`006P3oool00`3o_g@0
M;oo0?ooo`050?ooo`030;mdM02oool0oooo02D0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0^0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0
oooo0?ooo`0l0?ooo`030000O`3oool0oooo00800000@`3oool00`000000oooo0?ooo`0E0?ooo`00
6P3oool00`3o_g@0000000000005000000030000M02oool0oooo02D0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0^0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0
?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`000000000004D0oooo00<000000?ooo`3oool0
5@3oool001X0oooo00<0okmd07Boo`3oool01@3oool00`2oM7@0_ooo0?ooo`080?ooo`050?noM000
000000000000001d_ol01@3oool00`2oM0000000001d_`030?ooo`030?oo_`1d0000000000@00000
00<0M;oo0?ooo`3oool00`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02d0oooo
00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03/0oooo
0P0000170?ooo`030000003oool0oooo01D0oooo000J0?ooo`030?noM01d_ol0oooo00D0oooo00<0
_gAd0;ooo`3oool0203oool01P2LB7@0_ooo0?ooo`3ookl0M01d0;ooo`@0oooo00<0_g@000000000
M;l0103oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo00@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0]0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0i0?ooo`80000000<0oooo0000O`3oool0AP3oool00`000000
oooo0?ooo`0E0?ooo`006P3oool00`3o_g@0M;oo0?ooo`050?ooo`030;mdM02oool0oooo00L0oooo
00<0okmd001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`0;0?ooo`030?noM00004P0W=oo00P0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0]0?ooo`030000O`3oool0oooo03d0oooo
00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0g0?ooo`8000000`3oool00`0007l0oooo
0?ooo`150?ooo`030000003oool0oooo01D0oooo000/0?ooo`030=nLB018W=l0oooo0080oooo00<0
okmd001d_`3oool0303oool00`3ogi`0B00004RLg`070?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0;03oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0
001o0?ooo`3oool0=@3oool2000000D0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?oo
o`0E0?ooo`00;03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00h0oooo00<0W4P0
04RLg`3oool01@3oool3000001D0001o00<000000000O`0007l0hP0007l2000004d0001o0`00000G
0?ooo`00;03oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000M;l0oooo00l0oooo00<0W4Qd0;oo
o`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02`0oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo0340oooo0P0000090?oo
o`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool002`0oooo00<0okmd04RLg`3o
ool00P3oool00`3OW4P0B9cO0?ooo`0:0?ooo`030=nLB01d_ol0oooo0080oooo00<0_g@007Boo`3o
ool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02`0oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo02l0oooo0P00000;0?ooo`03
0000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool002d0oooo00H0W4P007Boo`3oool0
omnL04P0M02oool;0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`050?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0:`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3o
ool0oooo03d0oooo00<0001o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0;0?ooo`030000O`3o
ool0oooo04D0oooo00<000000?ooo`3oool05@3oool002d0oooo00D0oono07@000000000001809cO
o`0=0?ooo`050?noM000000000000000B02Lgol01P3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo02/0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000
O`3oool0oooo02`0oooo0P00000>0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool0
5@3oool004X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0[0?ooo`030000O`3o
ool0oooo03d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0[0?ooo`030000003o
ool0oooo00h0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02X0oooo00<0001o0?ooo`3oool0?@3oool0
0`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo02T0oooo0P00000A0?ooo`030000O`3oool0
oooo04D0oooo00<000000?ooo`3oool05@3oool004X0oooo0P00000H0?ooo`030000003oool0oooo
02X0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
02P0oooo00<000000?ooo`3oool04@3oool00`0007l0oooo0?ooo`130?ooo`<000005`3oool004X0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Z0?ooo`030000O`3oool0oooo03d0
oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0W0?ooo`030000003oool0oooo0180
oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo02T0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`0m0?ooo`030000O`3oool0oooo02D0oooo0P00000E0?ooo`030000O`3oool0oooo04D0oooo
00<000000?ooo`3oool05@3oool004X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0Y0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?oo
o`0T0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?oo
o`0E0?ooo`008P3oool00`3o_g@0001809cOo`0U0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o
0?ooo`3oool08P3oool2000001P0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E
0?ooo`007`3oool0103ookl0M00000000000M;lW0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0:03oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o
0?ooo`3oool08@3oool00`000000oooo0?ooo`0H0?ooo`030000O`3oool0oooo04D0oooo00<00000
0?ooo`3oool05@3oool001d0oooo00@0gia80000000004P0W=oo:@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m
0?ooo`030000O`3oool0oooo0200oooo00<000000?ooo`3oool06@3oool00`0007l0oooo0?ooo`15
0?ooo`030000003oool0oooo01D0oooo000J0?ooo`040?oOW0180000000004RLgb`0oooo0P00000J
0?ooo`030000003oool0oooo02P0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m
0?ooo`030000O`3oool0oooo01h0oooo0P00000L0?ooo`030000O`3oool0oooo04<0oooo0`00000G
0?ooo`006@3oool00`3o_g@004RL0=ooo`0^0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool09`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?oo
o`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000O`3oool0oooo04D0oooo00<000000?oo
o`3oool05@3oool004X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0W0?ooo`03
0000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0L0?ooo`03
0000003oool0oooo01d0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00
BP3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02L0oooo00<0001o0?ooo`3oool0
?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool0
7P3oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo001:0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool09P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3o
ool0oooo03d0oooo00<0001o0?ooo`3oool06@3oool200000240oooo00<0001o0?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0E0?ooo`00BP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo02H0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0
oooo01P0oooo00<000000?ooo`3oool08@3oool00`0007l0oooo0?ooo`150?ooo`030000003oool0
oooo01D0oooo001:0?ooo`800000703oool00`000000oooo0?ooo`0V0?ooo`030000O`3oool0oooo
03d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo
0280oooo00<0001o0?ooo`3oool0@`3oool3000001L0oooo001:0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0
oooo00<0001o0?ooo`3oool05@3oool2000002D0oooo00<0001o0?ooo`3oool0A@3oool00`000000
oooo0?ooo`0E0?ooo`00BP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02D0oooo
00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo01@0oooo
00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo
001:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?oo
o`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool04`3oool00`000000oooo0?oo
o`0V0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool002d0oooo00D0okmd
000000000000000007Boo`050?ooo`030;md0000000007Bo00H0oooo00D0omnL04P0000000000000
07Boo`050?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo
0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool04P3oool00`000000oooo
0?ooo`0W0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool002d0oooo00H0
W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00P0oooo00<0_g@007Boo`3o
ool01@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02@0oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo0140oooo00<000000?ooo`3o
ool0:03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000/0?ooo`030?no
M000M;l0oooo0080oooo00<0gia804RLg`3oool03P3oool00`2oM000M;oo0?ooo`050?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`0m0?ooo`030000
O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0403oool00`000000oooo0?ooo`0Y0?ooo`030000
O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool002`0oooo00<0gia804RLg`3oool00P3o
ool00`3o_g@007Bo0?ooo`0:0?ooo`030=nLB0000000000000<0000000<0M;oo0?ooo`3oool00`3o
ool3000001d0001o00<000000000O`0007l0]P0007l00`000000001o0000O`1`0000O`<000005`3o
ool002`0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`060?noM00007@0
_ooo0?ooo`2oM000M;oo1P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02<0oooo
00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo00h0oooo
00<000000?ooo`3oool0:`3oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo
000/0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02`3oool01@3OW4P007Bo0?oo
o`2oM000M;oo00H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0S0?ooo`030000
O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0=0?ooo`030000
003oool0oooo02`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00;03o
ool00`3o_g@0B9cO0?ooo`020?ooo`030=nLB018W=l0oooo00`0oooo00@0W4P004RLg`2oM000M;oo
1P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02<0oooo00<0001o0?ooo`3oool0
?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool0
;@3oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000L0?ooo`030?oOW018
0000000000<0000000<007Bo0?ooo`3oool0203oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`d0
oooo00@0omnL04P0B018B000M;oo1P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0280oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
00/0oooo00<000000?ooo`3oool0;P3oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo
01D0oooo000J0?ooo`040=nLB0000000001d0;ooo`@0oooo00@0gia80000000007@0_ooo1`3oool0
1@3ookl0M0000000000004P0W=oo00l0oooo00<0okmd0000001d_ol01P3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0280oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?oo
o`0m0?ooo`030000O`3oool0oooo00X0oooo00<000000?ooo`3oool0;`3oool00`0007l0oooo0?oo
o`150?ooo`030000003oool0oooo01D0oooo000I0?ooo`030?noM000M;l0oooo00P0oooo00<0omnL
04Q8W03Oool08`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0280oooo00<0001o
0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo00T0oooo00<00000
0?ooo`3oool0<03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo001:0?oo
o`8000008@3oool00`000000oooo0?ooo`0Q0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`080?ooo`030000003oool0oooo0340oooo00<0001o0?oo
o`3oool0@`3oool3000001L0oooo001:0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool08@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0b0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3o
ool05@3oool004X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Q0?ooo`030000
O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`060?ooo`030000
003oool0oooo03<0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0?@3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo00D0oooo00<000000?ooo`3oool0=03o
ool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo001:0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0803oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0
oooo03d0oooo00<0001o0?ooo`3oool0103oool00`000000oooo0?ooo`0e0?ooo`030000O`3oool0
oooo04D0oooo00<000000?ooo`3oool05@3oool004X0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0P0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?@3oool00`00
07l0oooo0?ooo`030?ooo`030000003oool0oooo03H0oooo00<0001o0?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0E0?ooo`00703oool00`3ogi`0B0000000000300000003001d_`3oool0oooo02D0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0P0?ooo`030000O`3oool0oooo03d0
oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`020?ooo`030000003oool0oooo03L0
oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`006P3oool0103OW4P00000
0000M02oool40?ooo`040=nLB0000000001d0;ooob@0oooo0P00000S0?ooo`030000003oool0oooo
01l0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0m0?ooo`050000O`3oool0oooo
0?ooo`000000>P3oool00`0007l0oooo0?ooo`130?ooo`<000005`3oool001T0oooo00<0okmd001d
_`3oool0203oool00`3ogi`0B4RL0=ooo`0S0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool07`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00@0001o0?oo
o`3oool00000>`3oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo001:0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool07`3oool00`0007l0oooo0?ooo`0m0?oo
o`030000O`3oool0oooo03d0oooo00<0001o0?ooo`000000?03oool00`0007l0oooo0?ooo`150?oo
o`030000003oool0oooo01D0oooo001:0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool07`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`00
0000?03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo001:0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool07P3oool00`0007l0oooo0?ooo`0m0?ooo`030000
O`3oool0oooo03d0oooo00<0001o0000003oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000
003oool0oooo01D0oooo000I0?ooo`030?oo_`1dM;l0oooo00H0oooo00<0_gAd0;ooo`3oool09@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo00<0001o0?ooo`3oool0?@3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000003oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0E0?ooo`006@3oool00`3ookl0M00000000006000000030000M02oool0
oooo02D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0N0?ooo`030000O`3oool0
oooo03d0oooo00<0001o0?ooo`3oool0?03oool00`000000001o0?ooo`0m0?ooo`030000O`3oool0
oooo04D0oooo00<000000?ooo`3oool05@3oool001h0oooo00<0oono07@0M02oool0:@3oool20000
02D0oooo00<000000?ooo`3oool07@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
03/0oooo00<000000?ooo`0007l0?P3oool00`0007l0oooo0?ooo`130?ooo`<000005`3oool001h0
oooo00<0_g@000000000M;l0:@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01d0
oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0j0?ooo`040000003oool0oooo0000
Och0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00703oool0203OW7@0
W9ad04RLg`3oool0okmd0000M01dM7@0_ooo9P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo01d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0i0?ooo`050000003o
ool0oooo0?ooo`0007l0?P3oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo
000L0?ooo`030=nLB000B9`0gooo0080oooo00<0oono07@0M02oool09P3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?oo
o`0h0?ooo`030000003oool0oooo0080oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`150?ooo`030000003oool0oooo01D0oooo000L0?ooo`030=nLM02Lgol0oooo00<0oooo00<0_gAd
0;ooo`3oool0203oool01@3o_g@00000000000000000M;oo00D0oooo00<0_g@000000000M;l01P3o
ool01@2oM00000000000000007@0_ooo00D0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0L0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0=`3oool00`000000oooo
0?ooo`030?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo
0?ooo`0E0?ooo`00703oool00`3OW7@0W=oo0?ooo`0>0?ooo`0609a8M02oool0oooo0?oo_`1d07@0
_ooo103oool00`2oM0000000001d_`050?ooo`060=nLB000M;l0oooo0?ooo`3o_g@007Bo1@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01`0oooo00<0001o0?ooo`3oool0?@3oool0
0`0007l0oooo0?ooo`0g0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000N0?ooo`030=nLW02oool0oooo
00<0oooo00<0gibL0;ooo`3oool01@3oool00`3o_g@007Bo0?ooo`020?ooo`030=nLB018W=l0oooo
00X0oooo00<0oono07@0001d_ol00P3oool00`3ookl0M4RL0?ooo`040?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
03H0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo
04D0oooo00<000000?ooo`3oool05@3oool001h0oooo00<0gia80000000000000`0000000`0007@0
_ooo0?ooo`050?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool01`3o_g@0
04Q807@0M02oool0oooo0=nLB000M;l01@3oool3000002D0001o00<000000000O`0007l0U00007l0
0`000000001o0000O`2:0000O`<000005`3oool001h0oooo00P0gibL0;ooo`3oool0_ibL0=ooo`3o
ool0gibL0;ooo`H0oooo00<0gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oO
W018B9`0okmd0080000000<004RL0?ooo`3oool0103oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo01/0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0d0?ooo`030000
003oool0oooo00H0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000
003oool0oooo01D0oooo000N0?ooo`080=nLW02oool0oooo0;nLW03Oool0oooo0=nLW02oool60?oo
o`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02P3oool00`3ookl0M01d0;ooo`090?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool06`3oool00`0007l0oooo0?ooo`0m0?oo
o`030000O`3oool0oooo03@0oooo00<000000?ooo`3oool01P3oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool001h0oooo00P0giad09cOo`3o
okl0M01d0;ooo`3oool0_gAd0;ooo`H0oooo00<0okmd04RLg`3oool00P3oool00`3OW4P0B9cO0?oo
o`0;0?ooo`030;md0018W=l0oooo00P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`0K0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0<`3oool00`000000oooo0?oo
o`070?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?oo
o`0E0?ooo`007P3oool01`3ookl0M0000000M02ookl0M0000000001d_ol0203oool01P2LB000M;oo
0?ooo`3ogi`0B01d0;ooo``0oooo00<0oono07@00000M;l0203oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo01/0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0b0?oo
o`030000003oool0oooo00P0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?oo
o`030000003oool0oooo01D0oooo000]0?ooo`050?oo_`1d000000000000B02Lgol03`3oool0102o
M000000000000000B9`50?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool06P3oool0
0`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo0380oooo00<000000?ooo`3oool0203oool0
0`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool0
04X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0J0?ooo`030000O`3oool0oooo
03d0oooo00<0001o0?ooo`3oool0<@3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`006P3oool01@3o_g@0
000000000000B9`0gooo02/0oooo0P00000X0?ooo`030000003oool0oooo01X0oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo00<0001o0?oo
o`3oool0?03oool00`0007l0oooo0?ooo`130?ooo`<000005`3oool001X0oooo00<0okmd07Boo`3o
ool01@3oool00`2oM7@0_ooo0?ooo`0U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool06@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo0300oooo00<000000?ooo`3o
ool02P3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3o
ool05@3oool001X0oooo00<0okmd07Boo`3oool01@3oool00`2oM7@0_ooo0?ooo`0U0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool06@3oool00`0007l0oooo0?ooo`0m0?ooo`030000
O`3oool0oooo02l0oooo00<000000?ooo`3oool02`3oool00`0007l0oooo0?ooo`0l0?ooo`030000
O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool001X0oooo00<0okmd0000000000001@00
00000`0007@0_ooo0?ooo`0U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool06@3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo02h0oooo00<000000?ooo`3oool0303o
ool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3o
ool001X0oooo00<0okmd07Boo`3oool01@3oool00`2oM7@0_ooo0?ooo`0U0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool06@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0
oooo02d0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0
oooo04D0oooo00<000000?ooo`3oool05@3oool001X0oooo00<0okmd07Boo`3oool01@3oool00`2o
M7@0_ooo0?ooo`0U0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0603oool00`00
07l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo02d0oooo00<000000?ooo`3oool03@3oool00`00
07l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool001X0
oooo00D0okmd00000000000004RL0=ooo`0[0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0603oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo02`0oooo00<000000?oo
o`3oool03P3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?oo
o`3oool05@3oool004X0oooo0P00000Z0?ooo`030000003oool0oooo01P0oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0[0?ooo`030000003oool0oooo00l0oooo00<0001o0?ooo`3o
ool0?03oool00`0007l0oooo0?ooo`130?ooo`<000005`3oool004X0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0H0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0
:`3oool00`000000oooo0?ooo`0?0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0
A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo01L0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0Z0?ooo`030000003o
ool0oooo0100oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003o
ool0oooo01D0oooo000I0?ooo`030?noM000M;l0oooo00P0oooo00<0omnL04Q8W03Oool08`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01L0oooo00<0001o0?ooo`3oool0?@3oool0
0`0007l0oooo0?ooo`0Y0?ooo`030000003oool0oooo0140oooo00<0001o0?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000J0?ooo`040=nLB000000004RL
0=ooo`@0oooo00@0okmd0000000007@0_ooo903oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo01L0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0X0?ooo`030000003o
ool0oooo0180oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003o
ool0oooo01D0oooo000L0?ooo`030?oOW0180000000000<0000000<007Bo0?ooo`3oool09@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01H0oooo00<0001o0?ooo`3oool0?@3oool0
0`0007l0oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo00<0001o0?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo001:0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool05P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo
02L0oooo00<000000?ooo`3oool04`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo
04D0oooo00<000000?ooo`3oool05@3oool004X0oooo0P00000/0?ooo`030000003oool0oooo01H0
oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0V0?ooo`030000003oool0oooo01@0
oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`130?ooo`<000005`3oool004X0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0F0?ooo`030000O`3oool0oooo03d0oooo
00<0001o0?ooo`3oool09@3oool00`000000oooo0?ooo`0E0?ooo`030000O`3oool0oooo03`0oooo
00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?oo
o`0U0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?oo
o`150?ooo`030000003oool0oooo01D0oooo000]0?ooo`050?noM000000000000000001d_ol01@3o
ool00`2oM0000000001d_`050?ooo`050;md00000000000000000000M;l01P3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo01D0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`0T0?ooo`030000003oool0oooo01H0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo
0?ooo`150?ooo`030000003oool0oooo01D0oooo000H0?ooo`040?oog`2LB000001809cOoa40oooo
00H0W4Qd0;ooo`3oool0oono07@0M02oool40?ooo`030;md0000000007Bo00@0oooo00<0okmd001d
_`3oool00P3oool00`2oM4P0W=oo0?ooo`040?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool05@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo02<0oooo00<000000?oo
o`3oool05`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?oo
o`3oool05@3oool001L0oooo00D0okmd0000B02Lgol0oknL09cOo`0@0?ooo`030?noM000M;l0oooo
0080oooo00<0gia804RLg`3oool02P3oool00`3OW4P0B9cO0?ooo`020?ooo`030;md001d_ol0oooo
00@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0E0?ooo`030000O`3oool0oooo
03d0oooo00<0001o0?ooo`3oool08P3oool00`000000oooo0?ooo`0H0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`005P3oool0203ogi`0
B7Bo0?ooo`3oool0oknL09cOo`3OW9`0_ooo3P3oool00`3OW4P0B9cO0?ooo`020?ooo`030?noM000
M;l0oooo00X0oooo00<0okmd0018W03oool00P3oool00`2LB4P0W=oo0?ooo`040?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3o
ool0oooo0280oooo00<000000?ooo`3oool0603oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo04D0oooo00<000000?ooo`3oool05@3oool001D0oooo00<0oono07@00000000010000000
0`0007@0_ooo0?ooo`0=0?ooo`030=nLB018W=l0oooo0080oooo00<0okmd001d_`3oool02`3oool0
1@3OW4P00000000000000000B9cO00H0oooo0`00000]0000O`030000000007l0001o07P0001o00<0
00000000O`0007l0WP0007l3000001L0oooo000J0?ooo`040?noW02Lgol0gibL0;ooo`h0oooo00<0
gia804RLg`3oool00P3oool00`3o_g@007Bo0?ooo`0:0?ooo`030?oo_`1dB9`0oooo0080oooo00<0
W4Qd0;ooo`3oool0103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0oooo00<0
001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0P0?ooo`030000003oool0oooo01X0oooo00<0
001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000/
0?ooo`030?noM018W=l0oooo0080oooo00<0gia804RLg`3oool02P3oool00`3o_g@0B9cO0?ooo`02
0?ooo`030;md001d_ol0oooo00@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0C
0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`0K
0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E
0?ooo`00;@3oool01P2LB000M;oo0?ooo`3ogi`0B01d0;ooo`/0oooo00L0omnL04P0M02oool0oooo
0?oOW01807@0_ooo00D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0C0?ooo`03
0000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool07`3oool00`000000oooo0?ooo`0K0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00
;@3oool01@3ookl0M0000000000004P0W=oo00d0oooo00D0okmd000000000000001809cOo`060?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool04`3oool00`0007l0oooo0?ooo`0m0?oo
o`030000O`3oool0oooo01h0oooo00<000000?ooo`3oool0703oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool00280oooo00<0okmd0000B02L
gol09@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0180oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0M0?ooo`030000003oool0oooo01d0oooo00<0001o0?ooo`3o
ool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000O0?ooo`040?oo
_`1d00000000001d_bL0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`03
0000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00
7@3oool0103OW4P000000000B02LgolY0?ooo`800000<03oool00`000000oooo0?ooo`0B0?ooo`03
0000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0@`3oool3000001L0oooo000J0?ooo`040?oO
W0180000000004RLgb`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0A0?ooo`03
0000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0703oool00`000000oooo0?ooo`0N0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00
6@3oool00`3o_g@004RL0=ooo`0^0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
4@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo01/0oooo00<000000?ooo`3oool0
7`3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool0
5@3oool004X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0A0?ooo`030000O`3o
ool0oooo03d0oooo00<0001o0?ooo`3oool06P3oool00`000000oooo0?ooo`0P0?ooo`030000O`3o
ool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0100oooo00<0001o0?ooo`3oool0?@3oool0
0`0007l0oooo0?ooo`0J0?ooo`030000003oool0oooo0200oooo00<0001o0?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000Q0?ooo`030?oog`2LB7@0_ooo
02H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0@0?ooo`030000O`3oool0oooo
03d0oooo00<0001o0?ooo`3oool06@3oool00`000000oooo0?ooo`0Q0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`007@3oool01P3OW9`0
_ooo0?ooo`3oool0gia807BoobL0oooo0P00000b0?ooo`030000003oool0oooo0100oooo00<0001o
0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0H0?ooo`030000003oool0oooo0280oooo00<0001o
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`130?ooo`<000005`3oool001d0oooo00D0gibL0;oo
o`3OW4P0000004RLg`0X0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool03`3oool0
0`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo01P0oooo00<000000?ooo`3oool08P3oool0
0`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool0
01d0oooo00<0gia800000018W=l0:P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
00l0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0G0?ooo`030000003oool0oooo
02<0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo
01D0oooo000M0?ooo`030=nLW02oool0oooo02X0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0?0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool05`3oool00`000000
oooo0?ooo`0S0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000
oooo0?ooo`0E0?ooo`007@3oool00`3OW9`0_ooo0?ooo`0Z0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo01H0oooo
00<000000?ooo`3oool0903oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo
00<000000?ooo`3oool05@3oool001d0oooo00H0gibL0;oo_`1d000000000000B02LgolW0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool03P3oool00`0007l0oooo0?ooo`0m0?ooo`03
0000O`3oool0oooo01D0oooo00<000000?ooo`3oool09@3oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool001d0oooo00L0gia80000M02oool0
oooo0?oog`2LM9`0gooo02H0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?oo
o`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool05@3oool00`000000oooo0?ooo`0U0?oo
o`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?oo
o`007@3oool00`3OW9`0_ooo0?ooo`0Z0?ooo`800000=@3oool00`000000oooo0?ooo`0=0?ooo`03
0000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0503oool00`000000oooo0?ooo`0V0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0@`3oool3000001L0oooo001:0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool03@3oool00`0007l0oooo0?ooo`0m0?ooo`030000
O`3oool0oooo01<0oooo00<000000?ooo`3oool09`3oool00`0007l0oooo0?ooo`0l0?ooo`030000
O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool001H0oooo00<0omnL04Q8W03Oool00P3o
ool00`3o_g@0001d0;ooo`0/0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool03@3o
ool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo01<0oooo00<000000?ooo`3oool09`3o
ool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3o
ool001D0oooo00<0oooO09adW03Oool00P3oool0103o_g@007Bo0=nLW02oool/0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3o
ool0oooo0180oooo00<000000?ooo`3oool0:03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3o
ool0oooo04D0oooo00<000000?ooo`3oool05@3oool001D0oooo00T0oono09bLg`3oool0oooo0?no
M000M;l0oooo0=nLW02oool0803oool00`3o_g@000000000000300000003001d_`3oool0oooo00<0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0<0?ooo`030000O`3oool0oooo03d0
oooo00<0001o0?ooo`3oool04P3oool00`000000oooo0?ooo`0X0?ooo`030000O`3oool0oooo03`0
oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`005@3oool01@3ooml0W7BL
0=ooo`3o_g@007Bo0080oooo00<0gibL0;ooo`3oool08P3oool00`2LB4P0W=oo0?ooo`060?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool0303oool00`0007l0oooo0?ooo`0m0?ooo`03
0000O`3oool0oooo0140oooo00<000000?ooo`3oool0:@3oool00`0007l0oooo0?ooo`0l0?ooo`03
0000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool001H0oooo00<0omnL04P00000M;l0
0P3oool00`3ookl0M01d0;ooo`0S0?ooo`0309a8B02Lgol0oooo00H0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0
403oool00`000000oooo0?ooo`0Z0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0
A@3oool00`000000oooo0?ooo`0E0?ooo`00@@3oool00`2LB4P0W=oo0?ooo`060?ooo`<00000=P00
07l00`000000001o0000O`1N0000O`030000000007l0001o0:l0001o0`00000G0?ooo`006`3oool0
0`3ooml0W9bo0?ooo`040?ooo`030=nLW02oool0oooo01`0oooo00<0W4Q809cOo`3oool01P3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool0?@3oool0
0`0007l0oooo0?ooo`0?0?ooo`030000003oool0oooo02/0oooo00<0001o0?ooo`3oool0?03oool0
0`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000K0?ooo`050?noW02Lgol0oooo
0?ooo`3OW4P00P0000000`0007@0_ooo0?ooo`0L0?ooo`0309a8B02Lgol0oooo00H0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0:0?ooo`030000O`3oool0oooo03d0oooo00<0001o
0?ooo`3oool03P3oool00`000000oooo0?ooo`0/0?ooo`030000O`3oool0oooo03`0oooo00<0001o
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`3o_i`0M;no09a800030000
000504RLg`3oool0oooo0=nLW02oool07@3oool00`2LB4P0W=oo0?ooo`060?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool02P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0
oooo00h0oooo00<000000?ooo`3oool0;03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0
oooo04D0oooo00<000000?ooo`3oool05@3oool001T0oooo00H0okmd04Q8M02Lgol0oooo0?oog`2L
W;lO0?ooo`050=nLB000000004RL09a8B02Lgol01`3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00X0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0=0?ooo`030000
003oool0oooo02d0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000
003oool0oooo01D0oooo000I0?ooo`060?oog`2LW;l0oooo0?ooo`3o_i`0W=oo8@3oool00`3OW4P0
001809cOo`070?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool02@3oool00`0007l0
oooo0?ooo`0m0?ooo`030000O`3oool0oooo00`0oooo00<000000?ooo`3oool0;P3oool00`0007l0
oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool001d0oooo
00<0gibL0;ooo`3oool00P3oool00`3OW9`0_ooo0?ooo`0U0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo00`0oooo
00<000000?ooo`3oool0;P3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo
00<000000?ooo`3oool05@3oool001d0oooo00<0giad09cOo`3o_g@00P0000000`0007@0_ooo0?oo
o`0U0?ooo`800000>@3oool00`000000oooo0?ooo`090?ooo`030000O`3oool0oooo03d0oooo00<0
001o0?ooo`3oool02`3oool00`000000oooo0?ooo`0_0?ooo`030000O`3oool0oooo03`0oooo00<0
001o0?ooo`3oool0@`3oool3000001L0oooo000M0?ooo`030?oo_`1d000007Bo0080oooo00<0gibL
0;ooo`3oool09@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00P0oooo00<0001o
0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0:0?ooo`030000003oool0oooo0300oooo00<0001o
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo001:0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0203oool00`0007l0oooo0?ooo`0m0?oo
o`030000O`3oool0oooo00X0oooo00<000000?ooo`3oool0<03oool00`0007l0oooo0?ooo`0l0?oo
o`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool004X0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`080?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3o
ool02@3oool00`000000oooo0?ooo`0a0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`3OW7@0W=oo0?ooo`020?ooo`030?oo
_`2LW=l0oooo02`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`070?ooo`030000
O`3oool0oooo03d0oooo00<0001o0?ooo`3oool02@3oool00`000000oooo0?ooo`0a0?ooo`030000
O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`005@3o
ool00`3ooml0W9bo0?ooo`040?ooo`030;nLW03Oool0oooo02/0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`070?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0203o
ool00`000000oooo0?ooo`0b0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0E0?ooo`005@3oool01@3ookl0W9cO0?ooo`3ookl0W9cO0080oooo00<0
gibL0;ooo`3oool0:`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00L0oooo00<0
001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`070?ooo`030000003oool0oooo03<0oooo00<0
001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000E
0?ooo`090?oog`2LM9`0gooo0?noM018M;l0gooo0?oo_`1dB9`0gooo02`0oooo0P00000l0?ooo`03
0000003oool0oooo00H0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`070?ooo`03
0000003oool0oooo03<0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`130?ooo`<0
00005`3oool001H0oooo00L0okmd00000000M;l0omnL04P0000004P0W=oo02d0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`060?ooo`030000O`3oool0oooo03d0oooo00<0001o0?oo
o`3oool01P3oool00`000000oooo0?ooo`0d0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?oo
o`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00D0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`050?ooo`03
0000003oool0oooo03D0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`03
0000003oool0oooo01D0oooo001:0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
1@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo00D0oooo00<000000?ooo`3oool0
=@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool0
5@3oool001d0oooo00D0oono07@000000000000004RLg`0X0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool01@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo00@0oooo
00<000000?ooo`3oool0=P3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo
00<000000?ooo`3oool05@3oool001`0oooo00<0oono07@0M02oool00P3oool00`3OW4P0B9cO0?oo
o`0V0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0103oool00`0007l0oooo0?oo
o`0m0?ooo`030000O`3oool0oooo00<0oooo00<000000?ooo`3oool0=`3oool00`0007l0oooo0?oo
o`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool001`0oooo00<0okmd
07Boo`3oool00`3oool00`2oW9`0gooo0?ooo`0U0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0103oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo0080oooo00<00000
0?ooo`3oool0>03oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<00000
0?ooo`3oool05@3oool001`0oooo00<0giad09cOo`3oool00`3oool00`2oM7@0_ooo0?ooo`0U0?oo
o`800000?`3oool00`000000oooo0?ooo`030?ooo`030000O`3oool0oooo03d0oooo00<0001o0?oo
o`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?oo
o`3oool0@`3oool3000001L0oooo000L0?ooo`030?noW02Lgol0oooo00<0oooo00<0_ibL0=ooo`3o
ool09@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00<0oooo00<0001o0?ooo`3o
ool0?@3oool01@0007l0oooo0?ooo`3oool0000003/0oooo00<0001o0?ooo`3oool0?03oool00`00
07l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000L0?ooo`030?oo_`1dM;l0oooo0080
oooo00<0oono07Ad_`3oool09P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0080
oooo00<0001o0?ooo`3oool0?@3oool0100007l0oooo0?ooo`00000l0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00703oool00`3OW4P0
0000001d_`020?ooo`030;mdM02oool0oooo00P0oooo00<0okmd0000000000000`0000000`00M;l0
oooo0?ooo`020?ooo`030;md0000000007Bo00<0oooo00<0oono07@000000000100000000`1d_ol0
oooo0?ooo`030?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool00P3oool00`0007l0
oooo0?ooo`0m0?ooo`030000O`3oool0000003d0oooo00<0001o0?ooo`3oool0?03oool00`0007l0
oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000_0?ooo`0309a8B02Lgol0oooo00D0oooo
00<0_g@000000000M;l0103oool00`2oM000001d0;ooo`020?ooo`030=nLM02Lgol0oooo00@0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`020?ooo`030000O`3oool0oooo03d0oooo
00<0001o0?ooo`000000?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo
00<000000?ooo`3oool05@3oool002l0oooo00<0W4Q809cOo`3oool03@3oool00`3o_g@0001809cO
o`080?ooo`030000003oool0oooo0400oooo00D000000?ooo`3oool0oooo0000O`0o0?ooo`030000
O`000000oooo03d0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000
003oool0oooo01D0oooo000F0?ooo`030?oOW018B9`0gooo0080oooo00<0okmd0000M02oool04@3o
ool00`2LB4P0W=oo0?ooo`0>0?ooo`030?oOW0180000B9cO00L0oooo00<000000?ooo`3oool0@03o
ool01@000000oooo0?ooo`3oool0001o03l0oooo00<000000?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool001D0oooo00<0
oooO09adW03Oool00P3oool0103o_g@007Bo0=nLW02ooolA0?ooo`0309a8B02Lgol0oooo0100oooo
00<0W4P004RLg`3oool01@3oool300000440001o00<000000000O`0007l0?`0007l00`000000001o
0000O`330000O`<000005`3oool001D0oooo00T0oono09bLg`3oool0oooo0?noM000M;l0oooo0=nL
W02oool04@3oool00`2LB4P0W=oo0?ooo`0A0?ooo`0309a8M02oool0oooo00@0oooo00<000000?oo
o`3oool0@@3oool010000000oooo0?ooo`0007lm0?ooo`030000003oool0001o03l0oooo00<0001o
0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0oooo000E0?oo
o`050?oog`2LM9`0gooo0?noM000M;l00P3oool00`3OW9`0_ooo0?ooo`0@0?ooo`0309a8B02Lgol0
oooo00`0oooo00<0gia807Boo`3oool00P3oool00`2oM000M;oo0?ooo`040?ooo`030000003oool0
oooo0480oooo00<000000?ooo`0007l0?@3oool00`000000oooo0000O`0o0?ooo`030000O`3oool0
oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`3o
gi`0B000001d_`020?ooo`030?oo_`1d07@0_ooo00h0oooo00D0gia800000000B9`0W4Q809cOo`0=
0?ooo`070?noM00007@0_ooo0?ooo`3o_g@0001809cOo`050?ooo`030000003oool0oooo0480oooo
00<000000?ooo`0007l0?03oool010000000oooo0?ooo`0007lo0?ooo`030000O`3oool0oooo03`0
oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00;P3oool00`3OW4P00018
09cOo`0>0?ooo`050?noM000000000000000B02Lgol01P3oool00`000000oooo0?ooo`130?ooo`03
0000000007l0oooo03X0oooo00D000000?ooo`3oool0oooo0000O`0o0?ooo`030000O`3oool0oooo
03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3oool00`000000
oooo0?ooo`130?ooo`030000000007l0oooo03T0oooo00<000000?ooo`3oool00P3oool00`0007l0
oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000
oooo0?ooo`0E0?ooo`00BP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool00P3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo
00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`006@3oool00`3o_g@007Bo0?oo
o`080?ooo`030?oOW018B9`0gooo02<0oooo0P0000150?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool00`3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo00<0
001o0?ooo`3oool0@`3oool3000001L0oooo000J0?ooo`040=nLB000000004RL0=ooo`@0oooo00@0
okmd0000000007@0_ooo903oool00`000000oooo0?ooo`140?ooo`030000O`000000oooo03H0oooo
00<000000?ooo`3oool0103oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo
00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00703oool00`3ogi`0B0000000
000300000003001d_`3oool0oooo02D0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0000
000e0?ooo`030000003oool0oooo00D0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?oo
o`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool004X0oooo00<00000
0?ooo`3oool0A03oool00`0007l0oooo0000000d0?ooo`030000003oool0oooo00H0oooo00<0001o
0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<00000
0?ooo`3oool05@3oool004X0oooo00<000000?ooo`3oool0A03oool0100007l0oooo0?ooo`00000b
0?ooo`030000003oool0oooo00L0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0l
0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool004X0oooo00<000000?oo
o`3oool0A03oool0100007l0oooo0?ooo`00000a0?ooo`030000003oool0oooo00P0oooo00<0001o
0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<00000
0?ooo`3oool05@3oool004X0oooo00<000000?ooo`3oool0A03oool01@0007l0oooo0?ooo`3oool0
000002l0oooo00<000000?ooo`3oool02@3oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0
oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3oool20000
04D0oooo00<0001o0?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00X0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo
04<0oooo0`00000G0?ooo`00BP3oool00`000000oooo0?ooo`140?ooo`030000O`3oool0oooo0080
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0;0?ooo`030000O`3oool0oooo03d0
oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0
oooo001:0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool00`3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo
0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool004X0oooo00<0
00000?ooo`3oool0A03oool00`0007l0oooo0?ooo`030?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0303oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo00<0
001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00BP3oool00`000000oooo0?ooo`14
0?ooo`030000O`3oool0oooo00@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0=
0?ooo`030000O`3oool0oooo03d0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`15
0?ooo`030000003oool0oooo01D0oooo001:0?ooo`030000003oool0oooo04@0oooo00<0001o0?oo
o`3oool01@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo00<0001o0?oo
o`3oool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?oo
o`3oool05@3oool004X0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`060?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool00`0007l0oooo0?ooo`0m0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00
BP3oool2000004D0oooo00<0001o0?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo0100oooo00<0001o0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000
O`3oool0oooo04<0oooo0`00000G0?ooo`00BP3oool00`000000oooo0?ooo`140?ooo`030000O`3o
ool0oooo00P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`030000O`3o
ool0oooo03d0oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003o
ool0oooo01D0oooo001:0?ooo`030000003oool0oooo04@0oooo00<0001o0?ooo`3oool02@3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0180oooo00<0001o0?ooo`3oool0?@3oool0
0`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3oool05@3oool0
02`0oooo00<0okmd0000000000000`0000000`00M;l0oooo0?ooo`020?ooo`030;md0000000007Bo
00H0oooo00D0omnL04P000000000000007Boo`050?ooo`030000003oool0oooo04@0oooo00<0001o
0?ooo`3oool02P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01<0oooo00<0001o
0?ooo`3oool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<00000
0?ooo`3oool05@3oool002l0oooo00<0W4Q809cOo`3oool01@3oool00`2oM0000000001d_`080?oo
o`030;md001d_ol0oooo00D0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0;0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0503oool00`0007l0oooo0?ooo`0m0?oo
o`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?oo
o`00;`3oool00`2LB4P0W=oo0?ooo`0@0?ooo`030;md001d_ol0oooo00D0oooo00<000000?ooo`3o
ool0A03oool00`0007l0oooo0?ooo`0<0?ooo`8000005P3oool2000001L0oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3o
ool05@3oool002l0oooo00<0W4Q809cOo`3oool0303oool00`3OW4P00000000000030000000307Bo
o`3oool0oooo00<0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0>0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`0007l0oooo0?ooo`0m0?ooo`030000
O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00;`3o
ool00`2LB4P0W=oo0?ooo`0<0?ooo`060?noM00007@0_ooo0?ooo`2oM000M;oo1P3oool3000005H0
001o00<000000000O`0007l03`0007l200000=l0001o0`00000G0?ooo`00;`3oool00`2LB4P0W=oo
0?ooo`0=0?ooo`050=nLB000M;l0oooo0;md001d_ol01P3oool00`000000oooo0?ooo`140?ooo`03
0000O`3oool0oooo0100oooo0P00000=0?ooo`800000703oool00`0007l0oooo0?ooo`0m0?ooo`03
0000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0E0?ooo`00
;`3oool00`2LB4P0W=oo0?ooo`0>0?ooo`0409a80018W=l0_g@007Boo`H0oooo00<000000?ooo`3o
ool0A03oool00`0007l0oooo0?ooo`0B0?ooo`D000000`3oool5000001h0oooo00<0001o0?ooo`3o
ool0?@3oool00`0007l0oooo0?ooo`0l0?ooo`030000O`3oool0oooo04D0oooo00<000000?ooo`3o
ool05@3oool002`0oooo00D0gia800000000B9`0W4Q809cOo`0?0?ooo`040?oOW01804P0B4P007Bo
o`H0oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0F0?ooo`@000008`3oool00`00
07l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03`0oooo00<0001o0?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0E0?ooo`00;P3oool00`3OW4P0001809cOo`0@0?ooo`030?noM0000000M;oo00H0
oooo00<000000?ooo`3oool0A03oool00`0007l0oooo0?ooo`0m0?ooo`030000O`3oool0oooo03d0
oooo00<0001o0?ooo`3oool0?03oool00`0007l0oooo0?ooo`150?ooo`030000003oool0oooo01D0
oooo001:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05@3oool004X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`00BP3ooooo0000050000005`3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
0?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool00?l0oooo/@3oool0
09`0oooo00D0_g@000000000000000000018W0040?ooo`0309a800000000000000<0000000@004RL
0?ooo`3oool0gia80`0000001@00M7@0M0000000B02Lgol0gia80080000000<004RL0?ooo`2oM000
0P0000001018W=l0oooo0?ooo`3OW4P3000000090000B02Lgol0oooo0?ooo`2oM000000004RLg`3o
ool0W4P00080000000<0B9cO0?ooo`3oool01`3oool00`3ogi`0B00000000003000000050000B02L
gol0oooo0?ooo`2LB0001@0000001000B9`0oooo0?ooo`2oM004000000030018W03oool0oooo0080
oooo00D0oono07@00000000000000018W0020?ooo`030?oo_`1d0000000000<0000000D0001809cO
o`3oool0oooo09a80005000000060018W03oool0W4P00000001dW9`0B0000P0000000`0007@0_ooo
0?ooo`020?ooo`0709a80000000000000018W02oM000000004RLg`020?ooo`050?oo_`1d00000000
00000000B9`00`3oool00`2LB000000000000003000000050018W03oool0oooo0?oo_`1d00000`00
0000100007@0_ooo0?ooo`3OW4P2000000030018W03oool0_g@00080000000<0B9cO0?ooo`3oool0
J03oool009d0oooo00<0_g@007Boo`3oool01`3oool00`3ookl0M01d0;ooo`030?ooo`030?oo_`1d
07@0_ooo0080oooo00<0_g@00000M02oool00P3oool00`3o_g@007Bo0?ooo`020?ooo`060;md001d
_ol0oooo0?ooo`3OW4P004RL0`3oool00`3ogi`0B01809cOo`020?ooo`050=nLB018W=l0oooo0=nL
B000M;l0303oool00`3ookl0M01d0;ooo`020?ooo`030?oOW018B9`0oooo00<0oooo00<0oono07@0
M02oool0103oool00`2oM000B9cO0?ooo`020?ooo`030=nLB018W=l0oooo0080oooo00L0gia804RL
g`3oool0oooo0=nLB00007@0_ooo0080oooo00<0oono07@0M02oool01`3oool00`3ookl0M01d0;oo
o`040?ooo`030;md000004P0W=oo0080oooo00H0okmd0018W03oool0oooo0?noM000B9`20?ooo`03
0=nLB0000000M;oo00<0oooo00L0gia804RLg`3oool0oooo0=nLB00007@0_ooo00<0oooo00<0oono
07@0M02oool0103oool00`2oM000M;oo0?ooo`020?ooo`060?noM000M;l0oooo0?ooo`3o_g@007Bo
0`3oool00`2oM000M;oo0?ooo`1Z0?ooo`00W@3oool00`2oM000M;oo0?ooo`070?ooo`030?oo_`1d
07@0_ooo00<0oooo00<0oono07@0B02Lgol00P3oool00`3ookl0M01d0;ooo`020?ooo`030?noM000
M;l0oooo0080oooo00H0_g@007Boo`3oool0oooo09a8B02Lgol80?ooo`040=nLB000B9`0gia80018
W0d0oooo00<0oono07@0M02oool00`3oool00`2oM000M;oo0?ooo`020?ooo`030?oo_`1d07@0_ooo
00T0oooo00<0_g@0001d_`3oool00P3oool00`3OW4P0B9cO0?ooo`060?ooo`030?oo_`1d07@0_ooo
00L0oooo00<0oono07@0M02oool0103oool00`2oM000M;oo0?ooo`030?ooo`050;mdB02Lgol0oooo
0=nLB018W=l00`3oool00`2oM000M;oo0?ooo`020?ooo`030=nLB018W=l0oooo00L0oooo00<0oono
07@0M02oool00`3oool00`3ookl0M4RL0?ooo`040?ooo`0509a8B02Lgol0oooo0?noM000M;l00`3o
ool00`2oM000M;oo0?ooo`1Z0?ooo`00W@3oool00`2oM0000000000000020000000307Boo`3oool0
oooo0080oooo00<0oono07@0M02oool0103oool00`3ogi`0B00000000002000000060000M02oool0
oooo0?ooo`3o_g@007Bo0`3oool01P2oM000M;oo0?ooo`3oool0W4Q809cOo`P0oooo00@0gia804Q8
B00004P0W=oo3@3oool00`3ookl0M01d0;ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0oono
07@0M02oool01@3oool01@2LB000000000000000000004RL00@0oooo00<0gia804RLg`3oool01P3o
ool00`3ookl0M01d0;ooo`070?ooo`030?oo_`1d07@0_ooo00@0oooo00<0_g@004RLg`3oool00`3o
ool01@2oM000M;oo0?ooo`3OW4P0B9cO00<0oooo00<0_g@007Boo`3oool00P3oool00`3OW4P0B9cO
0?ooo`070?ooo`030?oo_`1d07@0_ooo00<0oooo00<0oono07A8W03oool0103oool01@2LB4P0W=oo
0?ooo`3o_g@007Bo00<0oooo00<0_g@007Boo`3oool0JP3oool009d0oooo00L0_g@007Boo`3oool0
oooo0?oo_`1d07@0_ooo00<0oooo00<0oono07@0M02oool0103oool01`3ookl0_koo0?ooo`3oool0
omnL04P0M02oool00P3oool00`3o_g@0000007Boo`020?ooo`0709a8001d_ol0oooo0?ooo`3OW4P0
001d0;ooo`020?ooo`030;md000007@0_ooo0080oooo00@0gia804RLg`3ogi`0M9cO3@3oool00`3o
okl0M01d0;ooo`030?ooo`030=nLB018W=l0oooo0080oooo00<0oono07@0M02oool0103oool01`3o
_g@007Bo0?ooo`3oool0oono07@00018W=l00`3oool00`3OW4P0B9cO0?ooo`060?ooo`040?oo_`1d
0000000007Boo`H0oooo00<0oono07@0M02oool0103oool00`2oM000000004RLg`020?ooo`060=nL
B000B9`0oooo0?ooo`3OW4P0B9cO0`3oool00`2oM000M;oo0?ooo`020?ooo`030=nLB018W=l0oooo
00L0oooo00<0oono07@0M02oool0103oool00`2oM00004RL0?ooo`020?ooo`070;md0000M;l0oooo
0?ooo`3o_g@0000007Boo`020?ooo`0309a8001d_ol0oooo06X0oooo002M0?ooo`030;md001d_ol0
oooo0080oooo00<0_g@007Boo`3oool00P3oool00`3ookl0M01d0;ooo`040?ooo`060?oOW0180000
00000000000004P0W=oo0P3oool0103OW4P00000001dM01d000200000003001d_`3oool0oooo0080
oooo00L0okmd0000000000000000001dM01d07@0_ooo0080oooo00<0gia804RLW01d00000P000000
0`18W=l0oooo0?ooo`090?ooo`030?oo_`1d07@0_ooo00<0oooo00P0_g@007Boo`3oool0omnL04P0
00000000001d0;ooo`D0oooo00T0_g@0000000000000000007AdM018W=l0oooo0?oOW01800001000
00002@0004P0W=oo0?ooo`3oool0gia80000000007@0_ono07@000020000000707Boo`3oool0omnL
04P000000000001d0;ooo`040?ooo`030;md001d_ol0W4P00080000000h004RL0?ooo`3oool0gia8
00000018W=l0oooo0?oOW0180000000007Boo`3oool0omnL04P000@0000000T0001809cOo`3oool0
oooo0?oOW018000000000000M02oool01@3oool01@3OW4P0000000000000000007Bo0080oooo00@0
gia800000000M7@0M0000P0000000`00M;l0oooo0?ooo`1Z0?ooo`00W@3oool01`2oM000M;oo0?oo
o`3oool0omnL04P0M02oool00`3oool00`3ookl0M01d0;ooo`0P0?ooo`030=nLB018W=l0oooo00h0
oooo00<0oono07@0M02oool00P3oool00`3OW4P004RL0?ooo`0D0?ooo`030=nLB018W=l0oooo01L0
oooo00<0_g@007Boo`3oool0403oool00`3OW4P0B9cO0?ooo`290?ooo`00W03oool00`2oM0000000
00000002000000030000B02Lgol0oooo00<0oooo00<0oono07@0M02oool0803oool00`3OW4P0B9cO
0?ooo`0=0?ooo`030?oOW0180000000000<0000000<004RL0?ooo`3oool0503oool00`3OW4P0B9cO
0?ooo`0G0?ooo`030;md001d_ol0oooo0100oooo00<0gia804RLg`3oool0R@3oool00:D0oooo00D0
omnL04P000000000001d0;ooo`0O0?ooo`030;md00000000B9cO01X0oooo00<0okmd0000M02oool0
8@3oool00`3o_g@0001d0;ooo`030?ooo`030;md00000000M;oo01/0oooo00<0okmd0000M02oool0
O`3oool00>H0oooo00<0okmd0000M02oool08@3oool00`3o_g@0001d0;ooo`0Q0?ooo`030?noM000
07@0_ooo07l0oooo003o0?oook40oooo003o0?oook40oooo003o0?oook40oooo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.58908, -0.299679, \
0.0471747, 0.0108498}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseMain"],

Cell[CellGroupData[{

Cell["Self frying", "ExerciseTitle"],

Cell["\<\
Estimate how long a person can survive in a thermal suit that insulates \
perfectly.  If a body is not able to dissipate heat, normal metabolic \
processes will eventually drive the body temperature up to fatal levels.\
\>", "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Characteristic time for surface gravity", "ExerciseTitle"],

Cell[TextData[{
  "The gravitational acceleration experienced by a small body near the \
surface of a planet with mass ",
  StyleBox["M",
    FontSlant->"Italic"],
  " and radius ",
  StyleBox["R",
    FontSlant->"Italic"],
  " is"
}], "ExerciseText",
  Background->None],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox["",
            "TraditionalForm"], "g"}], "=", \(\(G\ M\)\/R\^2\)}], 
      TraditionalForm]], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->0,
  Background->None],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  " is the gravitational constant.  Find a combination of powers of ",
  StyleBox["G",
    FontSlant->"Italic"],
  ", ",
  StyleBox["M",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["R ",
    FontSlant->"Italic"],
  "with dimensions of time and compute this characteristic time for earth.  "
}], "ExerciseText",
  Background->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Gravitational acceleration for layered sphere", "ExerciseTitle"],

Cell[TextData[{
  "The following problem is based upon one written by MacDonald and employs \
the same data.  According to Newton's theory of gravity, the gravitational \
acceleration experienced by a small body at a distance ",
  Cell[BoxData[
      \(TraditionalForm\`r \[GreaterEqual] R\)]],
  "  from the center of a large spherical body of mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", which we refer to as a planet, is"
}], "ExerciseText",
  Background->None],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[\(g = \(G\ M\)\/r\^2\),
          "TraditionalForm"], " ", "for", " ", 
        FormBox[\(r \[GreaterEqual] R\),
          "TraditionalForm"]}], TraditionalForm]], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->0,
  Background->None],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " is the radius of the planet.  Imagine that there is  narrow tunnel \
drilled through the center of the planet and that the tunnel does not affect \
the gravitational interaction with the body.  As a consequence of the ",
  Cell[BoxData[
      \(TraditionalForm\`r\^\(-2\)\)]],
  " behavior of the gravitational force and the spherical distribution of \
mass, one can demonstrate that for ",
  Cell[BoxData[
      \(TraditionalForm\`r \[LessEqual] R\)]],
  " the gravitational acceleration is"
}], "ExerciseText",
  Background->None],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[\(g(r)\  = \(G\ \ \(M(r)\)\)\/r\^2\),
          "TraditionalForm"], " ", "for", " ", 
        FormBox[\(r \[LessEqual] R\),
          "TraditionalForm"]}], TraditionalForm]], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->0,
  Background->None],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`M(r)\)]],
  "  is the total mass contained within ",
  Cell[BoxData[
      \(TraditionalForm\`r \[LessEqual] R\)]],
  ".  In this problem we examine the effect of the mass distribution on the \
gravitational acceleration within the planet.\t\t\t"
}], "ExerciseText",
  Background->None],

Cell[TextData[{
  "a) It is useful to employ units in which ",
  Cell[BoxData[
      \(TraditionalForm\`G = 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`M = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R = 1\)]],
  ".  We call these relative units.\n\ti) What is the surface gravity \
(gravitational acceleration at ",
  Cell[BoxData[
      \(TraditionalForm\`r = R\)]],
  ") in these units?\n\tii) How does one recover conventional units given ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  "?  Check using parameters for the earth.\n\tiii) Find an expression for ",
  Cell[BoxData[
      \(TraditionalForm\`M(r)\)]],
  " in these units.  What is the average density in these units?"
}], "ExerciseText"],

Cell[TextData[{
  "b) First assume that the density of the planet is uniform.  Write a \
function ",
  StyleBox["g[uniform,r_]", "InlineInput",
    FontWeight->"Bold"],
  " which describes the shape of ",
  Cell[BoxData[
      \(TraditionalForm\`g(r)\)]],
  " for constant density in relative units.  Plot ",
  StyleBox["g[uniform,r]", "InlineInput",
    FontWeight->"Bold"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] r \[LessEqual] 2\)]],
  "."
}], "ExerciseText"],

Cell["\<\
c) Now consider a model in which the earth is layered like an onion.  For \
simplicity we consider only 3 layers, each assumed to have uniform density. \
\
\>", "ExerciseText"],

Cell[TextData[{
  "core",
  StyleBox[" \[Dash] contains 1.93 \[Cross] ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(10\^24\),
          FontSlant->"Plain"], TraditionalForm]]],
  " ",
  StyleBox["kilograms in a radius of 3490 kilometers.",
    FontSlant->"Plain"]
}], "ExerciseText",
  CellDingbat->"\[FilledSmallCircle]",
  TextAlignment->Left,
  FontSlant->"Italic"],

Cell[TextData[{
  StyleBox["mantle",
    FontSlant->"Italic"],
  " \[Dash] extends from the core to a radius of 6345 km and contains 4.01",
  StyleBox[" \[Cross] ",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(10\^24\),
          FontSlant->"Plain"], TraditionalForm]]],
  " ",
  StyleBox["kg",
    FontSlant->"Plain"]
}], "ExerciseText",
  CellDingbat->"\[FilledSmallCircle]",
  TextAlignment->Left],

Cell[TextData[{
  "crust",
  StyleBox[" \[Dash] outer shell 25 km in thickness containing 3.94 \[Cross] \
",
    FontSlant->"Plain"],
  Cell[BoxData[
      FormBox[
        StyleBox[\(10\^22\),
          FontSlant->"Plain"], TraditionalForm]]],
  " ",
  StyleBox["kg",
    FontSlant->"Plain"]
}], "ExerciseText",
  CellDingbat->"\[FilledSmallCircle]",
  TextAlignment->Left,
  FontSlant->"Italic"],

Cell["\<\
\ti) for each layer express the mass, inner radius, and outer radius in \
relative units
\tii) compute the density of each layer and compare with the average density \
in relative units\
\>", "ExerciseText"],

Cell[TextData[{
  "d) Write a function ",
  StyleBox["g[onion,r_]", "InlineInput",
    FontWeight->"Bold"],
  " that gives the gravitational acceleration that is produced by the layered \
mass distribution for any radius.  Be careful when evaluating the total mass \
",
  Cell[BoxData[
      \(TraditionalForm\`M(r)\)]],
  " contained within radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  "."
}], "ExerciseText"],

Cell["\<\
e) Plot the two models together and comment upon both the similarities and \
differences.  Be sure to examine the behavior within the crust also.\
\>", "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple-slit diffraction", "ExerciseTitle"],

Cell[TextData[{
  "The illumination of a distant screen by light that passes through ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " slits of width ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and spacing ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " is described by a diffraction pattern of the form"
}], "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`I[\[Theta]]\  = \ 
      I\_0\ f[n, d, \[Lambda], \[Theta]]\ g[
          a, \[Lambda], \[Theta]]\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`I\_0\)]],
  " is the intensity of the incident beam, "
}], "ExerciseText",
  CellDingbat->None],

Cell[BoxData[
    \(TraditionalForm\`f[n, d, \[Lambda], \[Theta]] = 
      Sin[n\ \[Pi]\ \(d\/\[Lambda]\) Sin[\[Theta]]]\^2\/Sin[\[Pi]\ \(d\/\
\[Lambda]\) Sin[\[Theta]]]\^2\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "is the ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-beam interference pattern, and "
}], "ExerciseText",
  CellDingbat->None],

Cell[BoxData[
    \(TraditionalForm\`g[a, \[Lambda], \[Theta]] = 
      Sin[\[Pi]\ \(a\/\[Lambda]\) Sin[\[Theta]]]\^2\/\((\[Pi]\ \(a\/\[Lambda]\
\) Sin[\[Theta]])\)\^2\)], "DisplayFormula",
  Evaluatable->False,
  TextAlignment->Left,
  TextJustification->0],

Cell["is the single-slit diffraction pattern.  ", "ExerciseText",
  CellDingbat->None],

Cell[TextData[{
  "a) Express ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " in terms of the dimensionless variables ",
  StyleBox["n",
    FontSlant->"Italic"],
  ", ",
  StyleBox["m",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["w",
    FontSlant->"Italic"],
  " where"
}], "ExerciseText"],

Cell[BoxData[
    \(TraditionalForm\`m\  = \ \(d\/\[Lambda]\) 
        Sin[\[Theta]]\)], "DisplayFormula",
  TextAlignment->Left,
  TextJustification->0],

Cell[TextData[{
  "is the fringe order and ",
  Cell[BoxData[
      \(TraditionalForm\`w = a/d\)]],
  " is the width relative to the spacing of the slits.  "
}], "ExerciseText"],

Cell[TextData[{
  "b) Find an expression which determines the location of the maxima in ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ".  It is important to distinguish between ",
  StyleBox["principal maxima",
    FontSlant->"Italic"],
  ", whose angular positions are independent of ",
  StyleBox["n",
    FontSlant->"Italic"],
  ", and smaller ",
  StyleBox["minor maxima.",
    FontSlant->"Italic"],
  " How many minor maxima are found between principal maxima for a given ",
  StyleBox["n",
    FontSlant->"Italic"],
  "?  Write a function which produces a list of positions for minor maxima in \
the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < m < 1\)]],
  "."
}], "ExerciseText"],

Cell[TextData[{
  "c) For what spacing ",
  StyleBox["d",
    FontSlant->"Italic"],
  " does a diffraction pattern for X-rays with \[Lambda] = 10 \[Angstrom] = \
",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-7\)\)]],
  " cm resemble that of the red light, \[Lambda] = 633 nm, emitted by a \
helium-neon laser impinging upon a grating with spacing ",
  StyleBox["d = ",
    FontSlant->"Italic"],
  "0.01 mm?  How about sound waves with \[Lambda] = 1 m?  For the present \
purposes we consider two diffraction patterns to be similar if the principal \
maxima have the same angular spacing.  Notice that the relationships between \
the parameters of the problem are much simpler when expressed in \
dimensionless form and that very similar patterns can observed over a wide \
range of scales.  The dimensionless forms describe the dynamics of a \
phenomenon, such as interference or diffraction, while the scales are \
determined by the structure of a system.\nd) Plot the diffraction pattern for \
",
  StyleBox["n",
    FontSlant->"Italic"],
  "=4 and ",
  StyleBox["w",
    FontSlant->"Italic"],
  "=0.5 as a function of ",
  StyleBox["m.",
    FontSlant->"Italic"],
  "  Does this figure care about length scales? "
}], "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 952}},
WindowToolbars->"EditBar",
WindowSize->{1392, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
ShowCellLabel->False,
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->PaperWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->7,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}, {
        Cell[ 
            TextData[ {"Essential Mathematica for Students of Science"}], 
            "Footer"], None, Cell[ 
            TextData[ {"\[Copyright] James J. Kelly, 1998"}], "Footer"]}},
    PageHeaderLines->{True, True},
    PageFooterLines->{True, True},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {0, 0}},
    CellGroupingRules->"TitleGrouping",
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontSize->34,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    FontSize->24,
    FontTracking->"Plain",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{0, 0}, {0, 0}},
    PageBreakBelow->False,
    LineSpacing->{1, 3},
    ParagraphIndent->-96,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 6},
    ParagraphIndent->-157,
    FontSize->30],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-78,
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{0, 0}, {0, 0}},
    ParagraphIndent->-85,
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    ShowCellBracket->True,
    CellMargins->{{10, 4}, {30, 10}},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {40, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    ShowCellBracket->True,
    CellMargins->{{8, 10}, {12, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    ShowCellBracket->True,
    CellMargins->{{9, 10}, {50, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 1}},
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {4, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{10, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{11, 10}, {8, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{8, Inherited}, {2, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {4, 40}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 12}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{29, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{21, 0}, {4, 20}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{9, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{9, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 6},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{13, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {2, 2}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{9, 0}, {4, 4}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellFrame->0.5,
    CellMargins->{{25, 10}, {8, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{5, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[1, 0.700008, 0.4]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{25, Inherited}, {10, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{25, 0}, {6, 6}}],
  
  Cell[StyleData["Input", "Printout"],
    CellFrame->0.5,
    CellMargins->{{25, 0}, {6, 6}},
    Background->None]
  }, Closed]],
  
  Cell[StyleData["InlineInput"],
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellFrame->True,
    CellMargins->{{25, 10}, {8, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 0.900008, 0.900008]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{25, Inherited}, {12, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{25, 0}, {6, 0}},
    CellElementSpacings->{"ClosedGroupTopMargin"->4},
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{50, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{62, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    CellMargins->{{74, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{52, Inherited}, {Inherited, Inherited}},
    ImageSize->{175, 175}],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    ImageSize->{250, 250}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->11,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->8],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{10, 4}, {2, 10}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Author", "Presentation"],
    CellMargins->{{12, 10}, {2, 12}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12},
    FontSize->16],
  
  Cell[StyleData["Author", "Condensed"],
    CellMargins->{{8, 10}, {1, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4},
    FontSize->9],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{9, 0}, {4, 12}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Copyright"],
    CellMargins->{{10, 10}, {40, 2}},
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Copyright", "Presentation"],
    CellMargins->{{12, 10}, {50, 2}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Copyright", "Condensed"],
    CellMargins->{{8, 10}, {12, 1}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["Copyright", "Printout"],
    CellMargins->{{9, 0}, {72, 4}},
    FontSize->7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{45, 75}, {Inherited, 30}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{36, 67}, {Inherited, 50}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Example"],
    CellMargins->{{12, 10}, {5, 12}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Example",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Example", "Presentation"],
    CellMargins->{{18, 10}, {8, 20}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Example", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 4}],
  
  Cell[StyleData["Example", "Printout"],
    CellMargins->{{9, 0}, {4, 10}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Definition"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Definition",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.2, 0.700008, 0.700008]],
  
  Cell[StyleData["Definition", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Definition", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Definition", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Theorem"],
    CellFrame->{{3, 0}, {0, 0}},
    CellMargins->{{52, 10}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Theorem",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["Theorem", "Presentation"],
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Theorem", "Condensed"],
    CellMargins->{{40, 10}, {1, 4}}],
  
  Cell[StyleData["Theorem", "Printout"],
    CellMargins->{{44, 0}, {2, 6}},
    Background->GrayLevel[0.4]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caution"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Caution",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Caution", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Caution", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Caution", "Printout"],
    CellFrame->False,
    CellDingbat->"\[WarningSign]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Advice"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{52, 25}, {8, 8}},
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    ShowStringCharacters->True,
    CounterIncrements->"Advice",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    Background->RGBColor[0, 1, 0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Advice", "Presentation"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{62, Inherited}, {5, 12}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Advice", "Condensed"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{40, 25}, {1, 4}}],
  
  Cell[StyleData["Advice", "Printout"],
    CellFrame->False,
    CellDingbat->"\[LightBulb]",
    CellMargins->{{44, 25}, {2, 6}},
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Exercise"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->"NormalGrouping",
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Exercise", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Exercise", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Exercise", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseMain"],
    CellFrame->{{6, 0}, {0, 1}},
    CellMargins->{{12, Inherited}, {4, 20}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0.571389, 0.19675, 0.570504],
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseMain", "Presentation"],
    CellMargins->{{18, 10}, {8, 32}},
    LineSpacing->{1, 2},
    FontSize->24,
    FontTracking->"Condensed"],
  
  Cell[StyleData["ExerciseMain", "Condensed"],
    CellMargins->{{9, 0}, {2, 50}},
    FontSize->14],
  
  Cell[StyleData["ExerciseMain", "Printout"],
    CellMargins->{{9, 0}, {2, 50}},
    CellFrameColor->GrayLevel[0.500008],
    FontSize->14,
    FontTracking->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseTitle"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Bold",
    FontColor->RGBColor[0.571389, 0.19675, 0.570504]],
  
  Cell[StyleData["ExerciseTitle", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["ExerciseTitle", "Condensed"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["ExerciseTitle", "Printout"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseText"],
    CellMargins->{{32, 10}, {5, 5}},
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExcersiceText",
    FontFamily->"Times"],
  
  Cell[StyleData["ExerciseText", "Presentation"],
    CellMargins->{{32, 10}, {8, 8}},
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["ExerciseText", "Condensed"],
    CellMargins->{{32, 0}, {4, 4}},
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 6}],
  
  Cell[StyleData["ExerciseText", "Printout"],
    CellMargins->{{32, 0}, {4, 4}},
    ParagraphSpacing->{0, 6}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Problem"],
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{23, Inherited}, {4, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->13,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Problem", "Presentation"],
    CellMargins->{{33, 10}, {8, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Problem", "Condensed"],
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11],
  
  Cell[StyleData["Problem", "Printout"],
    CellFrame->False,
    CellDingbat->"\[FilledDownTriangle]",
    CellMargins->{{9, 0}, {6, 20}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{62, 10}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{74, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{52, 10}, {2, 10}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, 10}, {2, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{12, 10}, {Inherited, 6}},
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{13, 30}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {Inherited, 4}},
    FontSize->9.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{9, 0}, {Inherited, 4}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{62, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    CellMargins->{{74, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    CellMargins->{{52, 10}, {Inherited, Inherited}}],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"]],
  
  Cell[StyleData["NumberedFigure", "Condensed"]],
  
  Cell[StyleData["NumberedFigure", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{62, 145}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"]],
  
  Cell[StyleData["NumberedTable", "Condensed"]],
  
  Cell[StyleData["NumberedTable", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontWeight->"Bold",
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1],
    FontVariations->{"Underline"->True}]
  }, Closed]]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3351098527-8632358"->{
    Cell[46521, 1211, 347, 9, 35, "Print",
      CellTags->"Info3351098527-8632358"]},
  "Info3351098591-5019139"->{
    Cell[48005, 1271, 352, 9, 35, "Print",
      CellTags->"Info3351098591-5019139"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3351098527-8632358", 259726, 6471},
  {"Info3351098591-5019139", 259843, 6474}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 86, 2, 81, "Title"],
Cell[1865, 57, 455, 15, 85, "Author"],

Cell[CellGroupData[{
Cell[2345, 76, 31, 0, 83, "Section"],
Cell[2379, 78, 1643, 24, 249, "Text"],
Cell[4025, 104, 117, 3, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4179, 112, 33, 0, 51, "Section"],
Cell[4215, 114, 117, 2, 99, "Input"],
Cell[4335, 118, 135, 2, 99, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4507, 125, 52, 0, 51, "Section"],
Cell[4562, 127, 444, 7, 93, "Text"],
Cell[5009, 136, 491, 18, 72, "Text"],

Cell[CellGroupData[{
Cell[5525, 158, 262, 4, 152, "Input"],
Cell[5790, 164, 38, 1, 59, "Output"]
}, Closed]],
Cell[5843, 168, 309, 5, 67, "Text"],
Cell[6155, 175, 319, 5, 152, "Input"],

Cell[CellGroupData[{
Cell[6499, 184, 148, 2, 95, "Input"],
Cell[6650, 188, 38, 1, 59, "Output"]
}, Closed]],
Cell[6703, 192, 866, 19, 119, "Text"],
Cell[7572, 213, 137, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[7734, 220, 130, 2, 74, "Input"],
Cell[7867, 224, 162, 2, 61, "Output"]
}, Closed]],
Cell[8044, 229, 53, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[8122, 233, 304, 6, 74, "Input"],
Cell[8429, 241, 509, 9, 84, "Output"]
}, Closed]],
Cell[8953, 253, 144, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[9122, 260, 267, 4, 74, "Input"],
Cell[9392, 266, 125, 2, 89, "Output"]
}, Closed]],
Cell[9532, 271, 132, 3, 41, "Text"],
Cell[9667, 276, 267, 6, 83, "Exercise"],
Cell[9937, 284, 352, 10, 84, "Exercise"],
Cell[10292, 296, 419, 11, 84, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[10748, 312, 24, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[10797, 316, 31, 0, 68, "Subsection"],
Cell[10831, 318, 1627, 30, 224, "Text"],
Cell[12461, 350, 702, 14, 120, "Text"],

Cell[CellGroupData[{
Cell[13188, 368, 71, 1, 73, "Input"],
Cell[13262, 371, 28157, 646, 370, "Print"]
}, Closed]],
Cell[41434, 1020, 58, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[41517, 1024, 54, 1, 73, "Input"],
Cell[41574, 1027, 80, 1, 83, "Output"]
}, Closed]],
Cell[41669, 1031, 98, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[41792, 1037, 238, 3, 125, "Input"],
Cell[42033, 1042, 283, 4, 89, "Output"]
}, Closed]],
Cell[42331, 1049, 372, 7, 67, "Text"],

Cell[CellGroupData[{
Cell[42728, 1060, 202, 4, 74, "Input"],
Cell[42933, 1066, 142, 2, 61, "Output"]
}, Closed]],
Cell[43090, 1071, 476, 7, 93, "Text"],

Cell[CellGroupData[{
Cell[43591, 1082, 68, 1, 73, "Input"],
Cell[43662, 1085, 255, 7, 59, "Output"]
}, Closed]],
Cell[43932, 1095, 87, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[44044, 1101, 98, 2, 73, "Input"],
Cell[44145, 1105, 45, 1, 61, "Output"]
}, Closed]],
Cell[44205, 1109, 65, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[44295, 1113, 330, 6, 73, "Input"],
Cell[44628, 1121, 117, 2, 61, "Output"]
}, Closed]],
Cell[44760, 1126, 234, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[45019, 1136, 43, 1, 73, "Input"],
Cell[45065, 1139, 55, 1, 61, "Output"]
}, Closed]],
Cell[45135, 1143, 195, 4, 41, "Text"],

Cell[CellGroupData[{
Cell[45355, 1151, 56, 1, 73, "Input"],
Cell[45414, 1154, 57, 1, 61, "Output"]
}, Closed]],
Cell[45486, 1158, 165, 3, 58, "Exercise"]
}, Closed]],

Cell[CellGroupData[{
Cell[45688, 1166, 33, 0, 68, "Subsection"],
Cell[45724, 1168, 318, 9, 42, "Text"],

Cell[CellGroupData[{
Cell[46067, 1181, 47, 1, 73, "Input"],
Cell[46117, 1184, 46, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[46200, 1190, 41, 1, 73, "Input"],
Cell[46244, 1193, 52, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[46333, 1199, 40, 1, 73, "Input"],
Cell[46376, 1202, 60, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[46473, 1208, 45, 1, 73, "Input"],
Cell[46521, 1211, 347, 9, 35, "Print",
  CellTags->"Info3351098527-8632358"]
}, Closed]],
Cell[46883, 1223, 361, 12, 42, "Text"],

Cell[CellGroupData[{
Cell[47269, 1239, 63, 1, 74, "Input"],
Cell[47335, 1242, 63, 1, 61, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[47435, 1248, 59, 1, 73, "Input"],
Cell[47497, 1251, 64, 1, 59, "Output"]
}, Closed]],
Cell[47576, 1255, 352, 9, 69, "Text"],

Cell[CellGroupData[{
Cell[47953, 1268, 49, 1, 73, "Input"],
Cell[48005, 1271, 352, 9, 35, "Print",
  CellTags->"Info3351098591-5019139"]
}, Closed]],

Cell[CellGroupData[{
Cell[48394, 1285, 79, 1, 73, "Input"],
Cell[48476, 1288, 41, 1, 59, "Output"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[48578, 1296, 59, 0, 51, "Section"],
Cell[48640, 1298, 351, 6, 67, "Text"],
Cell[48994, 1306, 192, 3, 177, "Input"],
Cell[49189, 1311, 426, 12, 69, "Text"],

Cell[CellGroupData[{
Cell[49640, 1327, 60, 1, 73, "Input"],
Cell[49703, 1330, 74, 1, 59, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[49814, 1336, 89, 2, 99, "Input"],
Cell[49906, 1340, 107, 2, 59, "Output"]
}, Closed]],
Cell[50028, 1345, 333, 8, 68, "Text"],

Cell[CellGroupData[{
Cell[50386, 1357, 98, 2, 99, "Input"],
Cell[50487, 1361, 86, 1, 59, "Output"]
}, Closed]],
Cell[50588, 1365, 99, 2, 41, "Text"],

Cell[CellGroupData[{
Cell[50712, 1371, 54, 1, 73, "Input"],
Cell[50769, 1374, 56, 1, 59, "Output"]
}, Closed]],
Cell[50840, 1378, 461, 15, 67, "Text"],
Cell[51304, 1395, 1132, 31, 121, "Text"],
Cell[52439, 1428, 277, 5, 206, "Input"],

Cell[CellGroupData[{
Cell[52741, 1437, 59, 1, 73, "Input"],
Cell[52803, 1440, 33520, 638, 279, 3801, 267, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[86338, 2081, 277, 5, 67, "Text"],
Cell[86618, 2088, 144, 2, 73, "Input"],

Cell[CellGroupData[{
Cell[86787, 2094, 62, 1, 73, "Input"],
Cell[86852, 2097, 90, 1, 61, "Output"]
}, Closed]],
Cell[86957, 2101, 195, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[87177, 2110, 73, 1, 73, "Input"],
Cell[87253, 2113, 2266, 60, 390, "Output"]
}, Closed]],
Cell[89534, 2176, 180, 4, 41, "Text"],

Cell[CellGroupData[{
Cell[89739, 2184, 71, 1, 73, "Input"],
Cell[89813, 2187, 76, 1, 59, "Output"]
}, Closed]],
Cell[89904, 2191, 303, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[90232, 2201, 66, 1, 73, "Input"],
Cell[90301, 2204, 64, 1, 59, "Output"]
}, Closed]],
Cell[90380, 2208, 219, 6, 41, "Text"],

Cell[CellGroupData[{
Cell[90624, 2218, 83, 2, 99, "Input"],
Cell[90710, 2222, 50, 1, 59, "Output"]
}, Closed]],
Cell[90775, 2226, 344, 9, 68, "Text"],
Cell[91122, 2237, 380, 8, 68, "Text"],
Cell[91505, 2247, 309, 6, 73, "Input"],

Cell[CellGroupData[{
Cell[91839, 2257, 63, 1, 73, "Input"],
Cell[91905, 2260, 52, 1, 59, "Output"]
}, Closed]],
Cell[91972, 2264, 337, 8, 67, "Text"],

Cell[CellGroupData[{
Cell[92334, 2276, 241, 5, 74, "Input"],
Cell[92578, 2283, 37732, 805, 279, 9055, 446, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[130325, 3091, 772, 16, 120, "Text"],
Cell[131100, 3109, 169, 3, 94, "Advice"]
}, Closed]],

Cell[CellGroupData[{
Cell[131306, 3117, 40, 0, 51, "Section"],
Cell[131349, 3119, 895, 13, 145, "Text"],
Cell[132247, 3134, 59, 0, 41, "Text"],

Cell[CellGroupData[{
Cell[132331, 3138, 219, 4, 130, "Input"],
Cell[132553, 3144, 152, 2, 110, "Output"]
}, Closed]],
Cell[132720, 3149, 176, 3, 41, "Text"],

Cell[CellGroupData[{
Cell[132921, 3156, 139, 3, 73, "Input"],
Cell[133063, 3161, 126, 2, 83, "Output"]
}, Closed]],
Cell[133204, 3166, 418, 9, 67, "Text"],

Cell[CellGroupData[{
Cell[133647, 3179, 478, 8, 156, "Input"],
Cell[134128, 3189, 80162, 1653, 279, 15700, 853, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[214339, 4848, 33, 0, 54, "ExerciseMain"],

Cell[CellGroupData[{
Cell[214397, 4852, 36, 0, 58, "ExerciseTitle"],
Cell[214436, 4854, 250, 4, 67, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[214723, 4863, 64, 0, 58, "ExerciseTitle"],
Cell[214790, 4865, 271, 10, 41, "ExerciseText"],
Cell[215064, 4877, 257, 9, 60, "DisplayFormula"],
Cell[215324, 4888, 411, 15, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[215772, 4908, 70, 0, 58, "ExerciseTitle"],
Cell[215845, 4910, 480, 11, 67, "ExerciseText"],
Cell[216328, 4923, 306, 9, 60, "DisplayFormula"],
Cell[216637, 4934, 612, 15, 93, "ExerciseText"],
Cell[217252, 4951, 317, 9, 61, "DisplayFormula"],
Cell[217572, 4962, 355, 10, 67, "ExerciseText"],
Cell[217930, 4974, 794, 24, 143, "ExerciseText"],
Cell[218727, 5000, 490, 15, 69, "ExerciseText"],
Cell[219220, 5017, 186, 4, 41, "ExerciseText"],
Cell[219409, 5023, 400, 14, 41, "ExerciseText"],
Cell[219812, 5039, 430, 15, 41, "ExerciseText"],
Cell[220245, 5056, 397, 15, 41, "ExerciseText"],
Cell[220645, 5073, 217, 5, 75, "ExerciseText"],
Cell[220865, 5080, 425, 13, 68, "ExerciseText"],
Cell[221293, 5095, 177, 3, 41, "ExerciseText"]
}, Closed]],

Cell[CellGroupData[{
Cell[221507, 5103, 50, 0, 58, "ExerciseTitle"],
Cell[221560, 5105, 347, 11, 41, "ExerciseText"],
Cell[221910, 5118, 225, 6, 41, "DisplayFormula",
  Evaluatable->False],
Cell[222138, 5126, 164, 6, 41, "ExerciseText"],
Cell[222305, 5134, 263, 6, 90, "DisplayFormula",
  Evaluatable->False],
Cell[222571, 5142, 148, 6, 41, "ExerciseText"],
Cell[222722, 5150, 258, 6, 86, "DisplayFormula",
  Evaluatable->False],
Cell[222983, 5158, 86, 1, 41, "ExerciseText"],
Cell[223072, 5161, 420, 20, 41, "ExerciseText"],
Cell[223495, 5183, 153, 4, 61, "DisplayFormula"],
Cell[223651, 5189, 177, 5, 41, "ExerciseText"],
Cell[223831, 5196, 703, 21, 93, "ExerciseText"],
Cell[224537, 5219, 1241, 30, 179, "ExerciseText"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

